diff --git a/src/plugins/duieditor/duieditor.pri b/src/plugins/duieditor/duieditor.pri
deleted file mode 100644
index c23c6294231829f146536c096f7c77905f841b42..0000000000000000000000000000000000000000
--- a/src/plugins/duieditor/duieditor.pri
+++ /dev/null
@@ -1,3 +0,0 @@
-include(duieditor_dependencies.pri)
-
-LIBS *= -l$$qtLibraryTarget(DuiEditor)
\ No newline at end of file
diff --git a/src/plugins/duieditor/duieditor.pro b/src/plugins/duieditor/duieditor.pro
deleted file mode 100644
index a02768c73e2035d25a8dcc531e1dbdacb58b6112..0000000000000000000000000000000000000000
--- a/src/plugins/duieditor/duieditor.pro
+++ /dev/null
@@ -1,49 +0,0 @@
-TEMPLATE = lib
-TARGET = DuiEditor
-include(../../qtcreatorplugin.pri)
-include(duieditor_dependencies.pri)
-include(parser/parser.pri)
-include(rewriter/rewriter.pri)
-DEFINES += DUIEDITOR_LIBRARY \
-    QT_CREATOR
-INCLUDEPATH += parser \
-    rewriter
-HEADERS += duieditor.h \
-    duieditorfactory.h \
-    duieditorplugin.h \
-    duihighlighter.h \
-    duieditoractionhandler.h \
-    duicodecompletion.h \
-    duieditorconstants.h \
-    duihoverhandler.h \
-    duidocument.h \
-    duicompletionvisitor.h \
-    duimodelmanagerinterface.h \
-    duieditor_global.h \
-    duimodelmanager.h \
-    duicodeformatter.h \
-    idcollector.h \
-    qmlexpressionundercursor.h \
-    qmllookupcontext.h \
-    qmlresolveexpression.h \
-    qmlsymbol.h \
-    qmlfilewizard.h
-SOURCES += duieditor.cpp \
-    duieditorfactory.cpp \
-    duieditorplugin.cpp \
-    duihighlighter.cpp \
-    duieditoractionhandler.cpp \
-    duicodecompletion.cpp \
-    duihoverhandler.cpp \
-    duidocument.cpp \
-    duicompletionvisitor.cpp \
-    duimodelmanagerinterface.cpp \
-    duimodelmanager.cpp \
-    duicodeformatter.cpp \
-    idcollector.cpp \
-    qmlexpressionundercursor.cpp \
-    qmllookupcontext.cpp \
-    qmlresolveexpression.cpp \
-    qmlsymbol.cpp \
-    qmlfilewizard.cpp
-RESOURCES += duieditor.qrc
diff --git a/src/plugins/duieditor/duieditor.qrc b/src/plugins/duieditor/duieditor.qrc
deleted file mode 100644
index 02442524da0d7f48cb24a142d17eba40f33c7be4..0000000000000000000000000000000000000000
--- a/src/plugins/duieditor/duieditor.qrc
+++ /dev/null
@@ -1,5 +0,0 @@
-<RCC>
-    <qresource prefix="/duieditor" >
-        <file>DuiEditor.mimetypes.xml</file>
-    </qresource>
-</RCC>
diff --git a/src/plugins/duieditor/duieditor_global.h b/src/plugins/duieditor/duieditor_global.h
deleted file mode 100644
index 27f1e2aa05f5e0af9da2a09d1ca3ed13a653a627..0000000000000000000000000000000000000000
--- a/src/plugins/duieditor/duieditor_global.h
+++ /dev/null
@@ -1,12 +0,0 @@
-#ifndef DUIEDITOR_GLOBAL_H
-#define DUIEDITOR_GLOBAL_H
-
-#include <QtGlobal>
-
-#if defined(DUIEDITOR_LIBRARY)
-#  define DUIEDITOR_EXPORT Q_DECL_EXPORT
-#else
-#  define DUIEDITOR_EXPORT Q_DECL_IMPORT
-#endif
-
-#endif // DUIEDITOR_GLOBAL_H
diff --git a/src/plugins/plugins.pro b/src/plugins/plugins.pro
index 0e084a0bff68e992a59f823de0e26de14f7162ca..44c0ddd032b022a5e9b9a24892ed37e1eb2d4306 100644
--- a/src/plugins/plugins.pro
+++ b/src/plugins/plugins.pro
@@ -32,7 +32,7 @@ SUBDIRS   = plugin_coreplugin \
             plugin_designer \
             plugin_resourceeditor \
             plugin_genericprojectmanager \
-            plugin_duieditor \
+            plugin_qmleditor \
             plugin_qmlprojectmanager \
             debugger/dumper.pro
 
@@ -169,12 +169,12 @@ plugin_genericprojectmanager.depends += plugin_projectexplorer
 plugin_genericprojectmanager.depends += plugin_cpptools
 plugin_genericprojectmanager.depends += plugin_cppeditor
 
-plugin_duieditor.subdir = duieditor
-plugin_duieditor.depends = plugin_texteditor
-plugin_duieditor.depends += plugin_coreplugin
+plugin_qmleditor.subdir = qmleditor
+plugin_qmleditor.depends = plugin_texteditor
+plugin_qmleditor.depends += plugin_coreplugin
 
 plugin_qmlprojectmanager.subdir = qmlprojectmanager
 plugin_qmlprojectmanager.depends = plugin_texteditor
 plugin_qmlprojectmanager.depends += plugin_projectexplorer
 plugin_qmlprojectmanager.depends += plugin_help
-plugin_qmlprojectmanager.depends += plugin_duieditor
+plugin_qmlprojectmanager.depends += plugin_qmleditor
diff --git a/src/plugins/duieditor/DuiEditor.mimetypes.xml b/src/plugins/qmleditor/QmlEditor.mimetypes.xml
similarity index 85%
rename from src/plugins/duieditor/DuiEditor.mimetypes.xml
rename to src/plugins/qmleditor/QmlEditor.mimetypes.xml
index 07261e30f32994505428871c6a89967df3401eea..60528b73c3a8bd1f18d47b016aa89dac09fd097c 100644
--- a/src/plugins/duieditor/DuiEditor.mimetypes.xml
+++ b/src/plugins/qmleditor/QmlEditor.mimetypes.xml
@@ -1,6 +1,6 @@
 <?xml version="1.0"?>
 <mime-info xmlns='http://www.freedesktop.org/standards/shared-mime-info'>
-    <mime-type type="application/x-dui">
+    <mime-type type="application/x-qml">
         <sub-class-of type="text/plain"/>
         <comment>QML file</comment>
         <glob pattern="*.qml"/>
diff --git a/src/plugins/duieditor/DuiEditor.pluginspec b/src/plugins/qmleditor/QmlEditor.pluginspec
similarity index 89%
rename from src/plugins/duieditor/DuiEditor.pluginspec
rename to src/plugins/qmleditor/QmlEditor.pluginspec
index 8272e77dc1551e830bbec7989465a07a1c46620c..6ede2aa85b3462b0a2b36bac7b5b7163dd9ce8c3 100644
--- a/src/plugins/duieditor/DuiEditor.pluginspec
+++ b/src/plugins/qmleditor/QmlEditor.pluginspec
@@ -1,4 +1,4 @@
-<plugin name="DuiEditor" version="1.2.91" compatVersion="1.2.91">
+<plugin name="QmlEditor" version="1.2.91" compatVersion="1.2.91">
     <vendor>Nokia Corporation</vendor>
     <copyright>(C) 2008-2009 Nokia Corporation</copyright>
     <license>
@@ -16,7 +16,7 @@ General Public License version 2.1 as published by the Free Software
 Foundation.  Please review the following information to
 ensure the GNU Lesser General Public License version 2.1 requirements
 will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.</license>
-    <description>Editor for DUI.</description>
+    <description>Editor for QML.</description>
     <url>http://qt.nokia.com</url>
     <dependencyList>
         <dependency name="Core" version="1.2.91"/>
diff --git a/src/plugins/duieditor/idcollector.cpp b/src/plugins/qmleditor/idcollector.cpp
similarity index 96%
rename from src/plugins/duieditor/idcollector.cpp
rename to src/plugins/qmleditor/idcollector.cpp
index 509fdc09b91fc9695397f7699502bb3f876433f3..8677d540fdbdf006fb5a7d690504800add0e5e42 100644
--- a/src/plugins/duieditor/idcollector.cpp
+++ b/src/plugins/qmleditor/idcollector.cpp
@@ -4,8 +4,8 @@
 
 using namespace QmlJS;
 using namespace QmlJS::AST;
-using namespace DuiEditor;
-using namespace DuiEditor::Internal;
+using namespace QmlEditor;
+using namespace QmlEditor::Internal;
 
 QMap<QString, QmlIdSymbol*> IdCollector::operator()(const QString &fileName, QmlJS::AST::UiProgram *ast)
 {
diff --git a/src/plugins/duieditor/idcollector.h b/src/plugins/qmleditor/idcollector.h
similarity index 95%
rename from src/plugins/duieditor/idcollector.h
rename to src/plugins/qmleditor/idcollector.h
index 17a7c547b92459d97b97e79b66f36736818a58cd..e4c7e7bf2925b1b205384420102bd000a0b8242e 100644
--- a/src/plugins/duieditor/idcollector.h
+++ b/src/plugins/qmleditor/idcollector.h
@@ -9,7 +9,7 @@
 #include "qmljsastvisitor_p.h"
 #include "qmlsymbol.h"
 
-namespace DuiEditor {
+namespace QmlEditor {
 namespace Internal {
 
 class IdCollector: protected QmlJS::AST::Visitor
@@ -35,6 +35,6 @@ private:
 };
 
 } // namespace Internal
-} // namespace DuiEditor
+} // namespace QmlEditor
 
 #endif // IDCOLLECTOR_H
diff --git a/src/plugins/duieditor/navigationtokenfinder.cpp b/src/plugins/qmleditor/navigationtokenfinder.cpp
similarity index 100%
rename from src/plugins/duieditor/navigationtokenfinder.cpp
rename to src/plugins/qmleditor/navigationtokenfinder.cpp
diff --git a/src/plugins/duieditor/parser/parser.pri b/src/plugins/qmleditor/parser/parser.pri
similarity index 100%
rename from src/plugins/duieditor/parser/parser.pri
rename to src/plugins/qmleditor/parser/parser.pri
diff --git a/src/plugins/duieditor/parser/qmljs.g b/src/plugins/qmleditor/parser/qmljs.g
similarity index 100%
rename from src/plugins/duieditor/parser/qmljs.g
rename to src/plugins/qmleditor/parser/qmljs.g
diff --git a/src/plugins/duieditor/parser/qmljsast.cpp b/src/plugins/qmleditor/parser/qmljsast.cpp
similarity index 100%
rename from src/plugins/duieditor/parser/qmljsast.cpp
rename to src/plugins/qmleditor/parser/qmljsast.cpp
diff --git a/src/plugins/duieditor/parser/qmljsast_p.h b/src/plugins/qmleditor/parser/qmljsast_p.h
similarity index 100%
rename from src/plugins/duieditor/parser/qmljsast_p.h
rename to src/plugins/qmleditor/parser/qmljsast_p.h
diff --git a/src/plugins/duieditor/parser/qmljsastfwd_p.h b/src/plugins/qmleditor/parser/qmljsastfwd_p.h
similarity index 100%
rename from src/plugins/duieditor/parser/qmljsastfwd_p.h
rename to src/plugins/qmleditor/parser/qmljsastfwd_p.h
diff --git a/src/plugins/duieditor/parser/qmljsastvisitor.cpp b/src/plugins/qmleditor/parser/qmljsastvisitor.cpp
similarity index 100%
rename from src/plugins/duieditor/parser/qmljsastvisitor.cpp
rename to src/plugins/qmleditor/parser/qmljsastvisitor.cpp
diff --git a/src/plugins/duieditor/parser/qmljsastvisitor_p.h b/src/plugins/qmleditor/parser/qmljsastvisitor_p.h
similarity index 100%
rename from src/plugins/duieditor/parser/qmljsastvisitor_p.h
rename to src/plugins/qmleditor/parser/qmljsastvisitor_p.h
diff --git a/src/plugins/duieditor/parser/qmljsengine_p.cpp b/src/plugins/qmleditor/parser/qmljsengine_p.cpp
similarity index 100%
rename from src/plugins/duieditor/parser/qmljsengine_p.cpp
rename to src/plugins/qmleditor/parser/qmljsengine_p.cpp
diff --git a/src/plugins/duieditor/parser/qmljsengine_p.h b/src/plugins/qmleditor/parser/qmljsengine_p.h
similarity index 100%
rename from src/plugins/duieditor/parser/qmljsengine_p.h
rename to src/plugins/qmleditor/parser/qmljsengine_p.h
diff --git a/src/plugins/duieditor/parser/qmljsglobal_p.h b/src/plugins/qmleditor/parser/qmljsglobal_p.h
similarity index 100%
rename from src/plugins/duieditor/parser/qmljsglobal_p.h
rename to src/plugins/qmleditor/parser/qmljsglobal_p.h
diff --git a/src/plugins/duieditor/parser/qmljsgrammar.cpp b/src/plugins/qmleditor/parser/qmljsgrammar.cpp
similarity index 100%
rename from src/plugins/duieditor/parser/qmljsgrammar.cpp
rename to src/plugins/qmleditor/parser/qmljsgrammar.cpp
diff --git a/src/plugins/duieditor/parser/qmljsgrammar_p.h b/src/plugins/qmleditor/parser/qmljsgrammar_p.h
similarity index 100%
rename from src/plugins/duieditor/parser/qmljsgrammar_p.h
rename to src/plugins/qmleditor/parser/qmljsgrammar_p.h
diff --git a/src/plugins/duieditor/parser/qmljslexer.cpp b/src/plugins/qmleditor/parser/qmljslexer.cpp
similarity index 100%
rename from src/plugins/duieditor/parser/qmljslexer.cpp
rename to src/plugins/qmleditor/parser/qmljslexer.cpp
diff --git a/src/plugins/duieditor/parser/qmljslexer_p.h b/src/plugins/qmleditor/parser/qmljslexer_p.h
similarity index 100%
rename from src/plugins/duieditor/parser/qmljslexer_p.h
rename to src/plugins/qmleditor/parser/qmljslexer_p.h
diff --git a/src/plugins/duieditor/parser/qmljsmemorypool_p.h b/src/plugins/qmleditor/parser/qmljsmemorypool_p.h
similarity index 100%
rename from src/plugins/duieditor/parser/qmljsmemorypool_p.h
rename to src/plugins/qmleditor/parser/qmljsmemorypool_p.h
diff --git a/src/plugins/duieditor/parser/qmljsnodepool_p.h b/src/plugins/qmleditor/parser/qmljsnodepool_p.h
similarity index 100%
rename from src/plugins/duieditor/parser/qmljsnodepool_p.h
rename to src/plugins/qmleditor/parser/qmljsnodepool_p.h
diff --git a/src/plugins/duieditor/parser/qmljsparser.cpp b/src/plugins/qmleditor/parser/qmljsparser.cpp
similarity index 100%
rename from src/plugins/duieditor/parser/qmljsparser.cpp
rename to src/plugins/qmleditor/parser/qmljsparser.cpp
diff --git a/src/plugins/duieditor/parser/qmljsparser_p.h b/src/plugins/qmleditor/parser/qmljsparser_p.h
similarity index 100%
rename from src/plugins/duieditor/parser/qmljsparser_p.h
rename to src/plugins/qmleditor/parser/qmljsparser_p.h
diff --git a/src/plugins/duieditor/duicodecompletion.cpp b/src/plugins/qmleditor/qmlcodecompletion.cpp
similarity index 81%
rename from src/plugins/duieditor/duicodecompletion.cpp
rename to src/plugins/qmleditor/qmlcodecompletion.cpp
index bdef36faaab74a10db267b2e7f9d189b8dff2a47..9626d2131956b94b30cc7f0dadde0b4fbdbfea71 100644
--- a/src/plugins/duieditor/duicodecompletion.cpp
+++ b/src/plugins/qmleditor/qmlcodecompletion.cpp
@@ -1,28 +1,28 @@
-#include "duicompletionvisitor.h"
-#include "duicodecompletion.h"
-#include "duieditor.h"
+#include "qmlcompletionvisitor.h"
+#include "qmlcodecompletion.h"
+#include "qmleditor.h"
 #include <texteditor/basetexteditor.h>
 #include <QtDebug>
 
-using namespace DuiEditor::Internal;
+using namespace QmlEditor::Internal;
 
-DuiCodeCompletion::DuiCodeCompletion(QObject *parent)
+QmlCodeCompletion::QmlCodeCompletion(QObject *parent)
     : TextEditor::ICompletionCollector(parent),
       m_editor(0),
       m_startPosition(0),
       m_caseSensitivity(Qt::CaseSensitive)
 { }
 
-DuiCodeCompletion::~DuiCodeCompletion()
+QmlCodeCompletion::~QmlCodeCompletion()
 { }
 
-Qt::CaseSensitivity DuiCodeCompletion::caseSensitivity() const
+Qt::CaseSensitivity QmlCodeCompletion::caseSensitivity() const
 { return m_caseSensitivity; }
 
-void DuiCodeCompletion::setCaseSensitivity(Qt::CaseSensitivity caseSensitivity)
+void QmlCodeCompletion::setCaseSensitivity(Qt::CaseSensitivity caseSensitivity)
 { m_caseSensitivity = caseSensitivity; }
 
-bool DuiCodeCompletion::supportsEditor(TextEditor::ITextEditable *editor)
+bool QmlCodeCompletion::supportsEditor(TextEditor::ITextEditable *editor)
 {
     if (qobject_cast<ScriptEditor *>(editor->widget()))
         return true;
@@ -30,10 +30,10 @@ bool DuiCodeCompletion::supportsEditor(TextEditor::ITextEditable *editor)
     return false;
 }
 
-bool DuiCodeCompletion::triggersCompletion(TextEditor::ITextEditable *)
+bool QmlCodeCompletion::triggersCompletion(TextEditor::ITextEditable *)
 { return false; }
 
-int DuiCodeCompletion::startCompletion(TextEditor::ITextEditable *editor)
+int QmlCodeCompletion::startCompletion(TextEditor::ITextEditable *editor)
 {
     m_editor = editor;
 
@@ -61,12 +61,12 @@ int DuiCodeCompletion::startCompletion(TextEditor::ITextEditable *editor)
         m_completions.append(item);
     }
 
-    DuiDocument::Ptr duiDocument = edit->duiDocument();
-    if (!duiDocument.isNull()) {
-        QmlJS::AST::UiProgram *program = duiDocument->program();
+    QmlDocument::Ptr qmlDocument = edit->qmlDocument();
+    if (!qmlDocument.isNull()) {
+        QmlJS::AST::UiProgram *program = qmlDocument->program();
 
         if (program) {
-            DuiCompletionVisitor visitor;
+            QmlCompletionVisitor visitor;
 
             foreach (const QString &word, visitor(program, m_startPosition)) {
                 TextEditor::CompletionItem item(this);
@@ -79,7 +79,7 @@ int DuiCodeCompletion::startCompletion(TextEditor::ITextEditable *editor)
     return pos;
 }
 
-void DuiCodeCompletion::completions(QList<TextEditor::CompletionItem> *completions)
+void QmlCodeCompletion::completions(QList<TextEditor::CompletionItem> *completions)
 {
     // ### FIXME: this code needs to be generalized.
 
@@ -128,7 +128,7 @@ void DuiCodeCompletion::completions(QList<TextEditor::CompletionItem> *completio
     }
 }
 
-void DuiCodeCompletion::complete(const TextEditor::CompletionItem &item)
+void QmlCodeCompletion::complete(const TextEditor::CompletionItem &item)
 {
     const QString toInsert = item.m_text;
     const int length = m_editor->position() - m_startPosition;
@@ -136,7 +136,7 @@ void DuiCodeCompletion::complete(const TextEditor::CompletionItem &item)
     m_editor->replace(length, toInsert);
 }
 
-bool DuiCodeCompletion::partiallyComplete(const QList<TextEditor::CompletionItem> &completionItems)
+bool QmlCodeCompletion::partiallyComplete(const QList<TextEditor::CompletionItem> &completionItems)
 {
     if (completionItems.count() == 1) {
         complete(completionItems.first());
@@ -163,7 +163,7 @@ bool DuiCodeCompletion::partiallyComplete(const QList<TextEditor::CompletionItem
     return false;
 }
 
-void DuiCodeCompletion::cleanup()
+void QmlCodeCompletion::cleanup()
 {
     m_editor = 0;
     m_startPosition = 0;
diff --git a/src/plugins/duieditor/duicodeformatter.cpp b/src/plugins/qmleditor/qmlcodeformatter.cpp
similarity index 73%
rename from src/plugins/duieditor/duicodeformatter.cpp
rename to src/plugins/qmleditor/qmlcodeformatter.cpp
index feb88982f8f21f4db8f0487e26bd25786700a8c9..9e14d9ed04425990f2f4d24b795e442a5991ca78 100644
--- a/src/plugins/duieditor/duicodeformatter.cpp
+++ b/src/plugins/qmleditor/qmlcodeformatter.cpp
@@ -1,19 +1,19 @@
-#include "duicodeformatter.h"
+#include "qmlcodeformatter.h"
 #include "qmljsast_p.h"
 
-using namespace DuiEditor::Internal;
+using namespace QmlEditor::Internal;
 using namespace QmlJS;
 using namespace QmlJS::AST;
 
-DuiCodeFormatter::DuiCodeFormatter()
+QmlCodeFormatter::QmlCodeFormatter()
 {
 }
 
-DuiCodeFormatter::~DuiCodeFormatter()
+QmlCodeFormatter::~QmlCodeFormatter()
 {
 }
 
-bool DuiCodeFormatter::visit(QmlJS::AST::UiProgram *ast)
+bool QmlCodeFormatter::visit(QmlJS::AST::UiProgram *ast)
 {
     Node::accept(ast->imports, this);
 
@@ -25,7 +25,7 @@ bool DuiCodeFormatter::visit(QmlJS::AST::UiProgram *ast)
     return false;
 }
 
-QString DuiCodeFormatter::operator()(QmlJS::AST::UiProgram *ast, const QString &originalSource, const QList<QmlJS::AST::SourceLocation> &comments, int start, int end)
+QString QmlCodeFormatter::operator()(QmlJS::AST::UiProgram *ast, const QString &originalSource, const QList<QmlJS::AST::SourceLocation> &comments, int start, int end)
 {
     m_result.clear();
     m_result.reserve(originalSource.length() * 2);
@@ -38,7 +38,7 @@ QString DuiCodeFormatter::operator()(QmlJS::AST::UiProgram *ast, const QString &
     return m_result;
 }
 
-bool DuiCodeFormatter::visit(UiImport *ast)
+bool QmlCodeFormatter::visit(UiImport *ast)
 {
     append("import ");
     append(ast->fileNameToken);
@@ -61,7 +61,7 @@ bool DuiCodeFormatter::visit(UiImport *ast)
     return false;
 }
 
-bool DuiCodeFormatter::visit(UiObjectDefinition *ast)
+bool QmlCodeFormatter::visit(UiObjectDefinition *ast)
 {
     indent();
     Node::accept(ast->qualifiedTypeNameId, this);
@@ -72,7 +72,7 @@ bool DuiCodeFormatter::visit(UiObjectDefinition *ast)
     return false;
 }
 
-bool DuiCodeFormatter::visit(QmlJS::AST::UiQualifiedId *ast)
+bool QmlCodeFormatter::visit(QmlJS::AST::UiQualifiedId *ast)
 {
     for (UiQualifiedId *it = ast; it; it = it->next) {
         append(it->name->asString());
@@ -84,7 +84,7 @@ bool DuiCodeFormatter::visit(QmlJS::AST::UiQualifiedId *ast)
     return false;
 }
 
-bool DuiCodeFormatter::visit(QmlJS::AST::UiObjectInitializer *ast)
+bool QmlCodeFormatter::visit(QmlJS::AST::UiObjectInitializer *ast)
 {
     append(ast->lbraceToken.offset, ast->rbraceToken.end() - ast->lbraceToken.offset);
 
diff --git a/src/plugins/duieditor/duicodeformatter.h b/src/plugins/qmleditor/qmlcodeformatter.h
similarity index 91%
rename from src/plugins/duieditor/duicodeformatter.h
rename to src/plugins/qmleditor/qmlcodeformatter.h
index ebb2ef57db88de9330295f3fa7312935e4bea37e..0cdc2d1e9f47b7b2bd91a27ce9e093972d2b4ae1 100644
--- a/src/plugins/duieditor/duicodeformatter.h
+++ b/src/plugins/qmleditor/qmlcodeformatter.h
@@ -1,5 +1,5 @@
-#ifndef DUICODEFORMATTER_H
-#define DUICODEFORMATTER_H
+#ifndef QMLCODEFORMATTER_H
+#define QMLCODEFORMATTER_H
 
 #include <QString>
 
@@ -7,14 +7,14 @@
 #include "qmljsastvisitor_p.h"
 #include "qmljsengine_p.h"
 
-namespace DuiEditor {
+namespace QmlEditor {
 namespace Internal {
 
-class DuiCodeFormatter: protected QmlJS::AST::Visitor
+class QmlCodeFormatter: protected QmlJS::AST::Visitor
 {
 public:
-    DuiCodeFormatter();
-    ~DuiCodeFormatter();
+    QmlCodeFormatter();
+    ~QmlCodeFormatter();
 
     QString operator()(QmlJS::AST::UiProgram *ast, const QString &originalSource, const QList<QmlJS::AST::SourceLocation> &comments, int start = -1, int end = -1);
 
@@ -77,6 +77,6 @@ private:
 };
 
 } // namespace Internal
-} // namespace DuiEditor
+} // namespace QmlEditor
 
-#endif // DUICODEFORMATTER_H
+#endif // QMLCODEFORMATTER_H
diff --git a/src/plugins/duieditor/duicompletionvisitor.cpp b/src/plugins/qmleditor/qmlcompletionvisitor.cpp
similarity index 84%
rename from src/plugins/duieditor/duicompletionvisitor.cpp
rename to src/plugins/qmleditor/qmlcompletionvisitor.cpp
index 2dd407b1f413ca143102ae98faf47deb2f8e5222..9150e2a93e79caedcfaf21721621e400305f8754 100644
--- a/src/plugins/duieditor/duicompletionvisitor.cpp
+++ b/src/plugins/qmleditor/qmlcompletionvisitor.cpp
@@ -1,19 +1,19 @@
 #include <QtCore/QDebug>
 
-#include "duicompletionvisitor.h"
+#include "qmlcompletionvisitor.h"
 #include "qmljsast_p.h"
 
 using namespace QmlJS;
 using namespace QmlJS::AST;
 
-namespace DuiEditor {
+namespace QmlEditor {
 namespace Internal {
 
-DuiCompletionVisitor::DuiCompletionVisitor()
+QmlCompletionVisitor::QmlCompletionVisitor()
 {
 }
 
-QSet<QString> DuiCompletionVisitor::operator()(QmlJS::AST::UiProgram *ast, int pos)
+QSet<QString> QmlCompletionVisitor::operator()(QmlJS::AST::UiProgram *ast, int pos)
 {
     m_completions.clear();
     m_pos = (quint32) pos;
@@ -23,7 +23,7 @@ QSet<QString> DuiCompletionVisitor::operator()(QmlJS::AST::UiProgram *ast, int p
     return m_completions;
 }
 
-bool DuiCompletionVisitor::preVisit(QmlJS::AST::Node *node)
+bool QmlCompletionVisitor::preVisit(QmlJS::AST::Node *node)
 {
     if (!m_parentStack.isEmpty())
         m_nodeParents[node] = m_parentStack.top();
@@ -42,7 +42,7 @@ static QString toString(Statement *stmt)
     return QString();
 }
 
-bool DuiCompletionVisitor::visit(UiScriptBinding *ast)
+bool QmlCompletionVisitor::visit(UiScriptBinding *ast)
 {
     if (!ast)
         return false;
@@ -71,7 +71,7 @@ bool DuiCompletionVisitor::visit(UiScriptBinding *ast)
     return true;
 }
 
-UiObjectDefinition *DuiCompletionVisitor::findParentObject(Node *node) const
+UiObjectDefinition *QmlCompletionVisitor::findParentObject(Node *node) const
 {
     if (!node)
         return 0;
@@ -87,4 +87,4 @@ UiObjectDefinition *DuiCompletionVisitor::findParentObject(Node *node) const
 }
 
 } // namespace Internal
-} // namespace DuiEditor
+} // namespace QmlEditor
diff --git a/src/plugins/duieditor/duicompletionvisitor.h b/src/plugins/qmleditor/qmlcompletionvisitor.h
similarity index 87%
rename from src/plugins/duieditor/duicompletionvisitor.h
rename to src/plugins/qmleditor/qmlcompletionvisitor.h
index 473ed160257979294d19366d4044179c5301c04f..ae223dffc466630d6e70ea9252e56b31c34db5fa 100644
--- a/src/plugins/duieditor/duicompletionvisitor.h
+++ b/src/plugins/qmleditor/qmlcompletionvisitor.h
@@ -10,13 +10,13 @@
 #include "qmljsastvisitor_p.h"
 #include "qmljsengine_p.h"
 
-namespace DuiEditor {
+namespace QmlEditor {
 namespace Internal {
 
-class DuiCompletionVisitor: protected QmlJS::AST::Visitor
+class QmlCompletionVisitor: protected QmlJS::AST::Visitor
 {
 public:
-    DuiCompletionVisitor();
+    QmlCompletionVisitor();
 
     QSet<QString> operator()(QmlJS::AST::UiProgram *ast, int pos);
 
@@ -38,6 +38,6 @@ private:
 };
 
 } // namespace Internal
-} // namespace DuiEditor
+} // namespace QmlEditor
 
 #endif // COMPLETIONVISITOR_H
diff --git a/src/plugins/duieditor/duidocument.cpp b/src/plugins/qmleditor/qmldocument.cpp
similarity index 77%
rename from src/plugins/duieditor/duidocument.cpp
rename to src/plugins/qmleditor/qmldocument.cpp
index f3b1761e56237c24e00dcb46fd448ad7d9890679..d89e69609f5fbad669ad91ab30af8faaf71f0af0 100644
--- a/src/plugins/duieditor/duidocument.cpp
+++ b/src/plugins/qmleditor/qmldocument.cpp
@@ -28,17 +28,17 @@
 **************************************************************************/
 
 #include "idcollector.h"
-#include "duidocument.h"
+#include "qmldocument.h"
 #include "qmljsast_p.h"
 #include "qmljslexer_p.h"
 #include "qmljsparser_p.h"
 #include "qmljsengine_p.h"
 #include "qmljsnodepool_p.h"
 
-using namespace DuiEditor;
+using namespace QmlEditor;
 using namespace QmlJS;
 
-DuiDocument::DuiDocument(const QString &fileName)
+QmlDocument::QmlDocument(const QString &fileName)
     : _engine(0)
     , _pool(0)
     , _program(0)
@@ -53,7 +53,7 @@ DuiDocument::DuiDocument(const QString &fileName)
         _componentName = fileName.mid(slashIdx + 1, fileName.size() - (slashIdx + 1) - 4);
 }
 
-DuiDocument::~DuiDocument()
+QmlDocument::~QmlDocument()
 {
     if (_engine)
         delete _engine;
@@ -64,33 +64,33 @@ DuiDocument::~DuiDocument()
     qDeleteAll(_ids.values());
 }
 
-DuiDocument::Ptr DuiDocument::create(const QString &fileName)
+QmlDocument::Ptr QmlDocument::create(const QString &fileName)
 {
-    DuiDocument::Ptr doc(new DuiDocument(fileName));
+    QmlDocument::Ptr doc(new QmlDocument(fileName));
     return doc;
 }
 
-AST::UiProgram *DuiDocument::program() const
+AST::UiProgram *QmlDocument::program() const
 {
     return _program;
 }
 
-QList<DiagnosticMessage> DuiDocument::diagnosticMessages() const
+QList<DiagnosticMessage> QmlDocument::diagnosticMessages() const
 {
     return _diagnosticMessages;
 }
 
-QString DuiDocument::source() const
+QString QmlDocument::source() const
 {
     return _source;
 }
 
-void DuiDocument::setSource(const QString &source)
+void QmlDocument::setSource(const QString &source)
 {
     _source = source;
 }
 
-bool DuiDocument::parse()
+bool QmlDocument::parse()
 {
     Q_ASSERT(! _engine);
     Q_ASSERT(! _pool);
@@ -125,18 +125,18 @@ Snapshot::~Snapshot()
 {
 }
 
-void Snapshot::insert(const DuiDocument::Ptr &document)
+void Snapshot::insert(const QmlDocument::Ptr &document)
 {
-    QMap<QString, DuiDocument::Ptr>::insert(document->fileName(), document);
+    QMap<QString, QmlDocument::Ptr>::insert(document->fileName(), document);
 }
 
-DuiDocument::PtrList Snapshot::importedDocuments(const DuiDocument::Ptr &doc, const QString &importPath) const
+QmlDocument::PtrList Snapshot::importedDocuments(const QmlDocument::Ptr &doc, const QString &importPath) const
 {
-    DuiDocument::PtrList result;
+    QmlDocument::PtrList result;
 
     const QString docPath = doc->path() + '/' + importPath;
 
-    foreach (DuiDocument::Ptr candidate, *this) {
+    foreach (QmlDocument::Ptr candidate, *this) {
         if (candidate == doc)
             continue;
 
@@ -147,13 +147,13 @@ DuiDocument::PtrList Snapshot::importedDocuments(const DuiDocument::Ptr &doc, co
     return result;
 }
 
-QMap<QString, DuiDocument::Ptr> Snapshot::componentsDefinedByImportedDocuments(const DuiDocument::Ptr &doc, const QString &importPath) const
+QMap<QString, QmlDocument::Ptr> Snapshot::componentsDefinedByImportedDocuments(const QmlDocument::Ptr &doc, const QString &importPath) const
 {
-    QMap<QString, DuiDocument::Ptr> result;
+    QMap<QString, QmlDocument::Ptr> result;
 
     const QString docPath = doc->path() + '/' + importPath;
 
-    foreach (DuiDocument::Ptr candidate, *this) {
+    foreach (QmlDocument::Ptr candidate, *this) {
         if (candidate == doc)
             continue;
 
diff --git a/src/plugins/duieditor/duieditor.cpp b/src/plugins/qmleditor/qmleditor.cpp
similarity index 95%
rename from src/plugins/duieditor/duieditor.cpp
rename to src/plugins/qmleditor/qmleditor.cpp
index 5063d56e59521aac946eb6a97a391f21999acb92..18c69ca7d20929d2b735e6e1c6d3a1bef8b1cd77 100644
--- a/src/plugins/duieditor/duieditor.cpp
+++ b/src/plugins/qmleditor/qmleditor.cpp
@@ -27,12 +27,12 @@
 **
 **************************************************************************/
 
-#include "duieditor.h"
-#include "duieditorconstants.h"
-#include "duihighlighter.h"
-#include "duieditorplugin.h"
-#include "duidocument.h"
-#include "duimodelmanager.h"
+#include "qmleditor.h"
+#include "qmleditorconstants.h"
+#include "qmlhighlighter.h"
+#include "qmleditorplugin.h"
+#include "qmldocument.h"
+#include "qmlmodelmanager.h"
 
 #include "qmljsastvisitor_p.h"
 #include "qmljsast_p.h"
@@ -70,7 +70,7 @@ enum {
 using namespace QmlJS;
 using namespace QmlJS::AST;
 
-namespace DuiEditor {
+namespace QmlEditor {
 namespace Internal {
 
 class FindWords: protected Visitor
@@ -379,7 +379,7 @@ ScriptEditor::ScriptEditor(const Context &context, QWidget *parent) :
     setMarksVisible(true);
     setCodeFoldingSupported(true);
     setCodeFoldingVisible(true);
-    setMimeType(DuiEditor::Constants::DUIEDITOR_MIMETYPE);
+    setMimeType(QmlEditor::Constants::QMLEDITOR_MIMETYPE);
 
     m_updateDocumentTimer = new QTimer(this);
     m_updateDocumentTimer->setInterval(UPDATE_DOCUMENT_DEFAULT_INTERVAL);
@@ -389,13 +389,13 @@ ScriptEditor::ScriptEditor(const Context &context, QWidget *parent) :
 
     connect(this, SIGNAL(textChanged()), this, SLOT(updateDocument()));
 
-    baseTextDocument()->setSyntaxHighlighter(new DuiHighlighter);
+    baseTextDocument()->setSyntaxHighlighter(new QmlHighlighter);
 
-    m_modelManager = ExtensionSystem::PluginManager::instance()->getObject<DuiModelManagerInterface>();
+    m_modelManager = ExtensionSystem::PluginManager::instance()->getObject<QmlModelManagerInterface>();
 
     if (m_modelManager) {
-        connect(m_modelManager, SIGNAL(documentUpdated(DuiDocument::Ptr)),
-                this, SLOT(onDocumentUpdated(DuiDocument::Ptr)));
+        connect(m_modelManager, SIGNAL(documentUpdated(QmlDocument::Ptr)),
+                this, SLOT(onDocumentUpdated(QmlDocument::Ptr)));
     }
 }
 
@@ -413,13 +413,13 @@ Core::IEditor *ScriptEditorEditable::duplicate(QWidget *parent)
 {
     ScriptEditor *newEditor = new ScriptEditor(m_context, parent);
     newEditor->duplicateFrom(editor());
-    DuiEditorPlugin::instance()->initializeEditor(newEditor);
+    QmlEditorPlugin::instance()->initializeEditor(newEditor);
     return newEditor->editableInterface();
 }
 
 const char *ScriptEditorEditable::kind() const
 {
-    return DuiEditor::Constants::C_DUIEDITOR;
+    return QmlEditor::Constants::C_QMLEDITOR;
 }
 
 ScriptEditor::Context ScriptEditorEditable::context() const
@@ -443,7 +443,7 @@ void ScriptEditor::updateDocumentNow()
     m_modelManager->updateSourceFiles(QStringList() << fileName);
 }
 
-void ScriptEditor::onDocumentUpdated(DuiDocument::Ptr doc)
+void ScriptEditor::onDocumentUpdated(QmlDocument::Ptr doc)
 {
     if (file()->fileName() != doc->fileName())
         return;
@@ -584,7 +584,7 @@ QStringList ScriptEditor::keywords() const
 {
     QStringList words;
 
-    if (DuiHighlighter *highlighter = qobject_cast<DuiHighlighter*>(baseTextDocument()->syntaxHighlighter()))
+    if (QmlHighlighter *highlighter = qobject_cast<QmlHighlighter*>(baseTextDocument()->syntaxHighlighter()))
         words = highlighter->keywords().toList();
 
     return words;
@@ -593,7 +593,7 @@ QStringList ScriptEditor::keywords() const
 void ScriptEditor::setFontSettings(const TextEditor::FontSettings &fs)
 {
     TextEditor::BaseTextEditor::setFontSettings(fs);
-    DuiHighlighter *highlighter = qobject_cast<DuiHighlighter*>(baseTextDocument()->syntaxHighlighter());
+    QmlHighlighter *highlighter = qobject_cast<QmlHighlighter*>(baseTextDocument()->syntaxHighlighter());
     if (!highlighter)
         return;
 
@@ -710,7 +710,7 @@ TextEditor::BaseTextEditor::Link ScriptEditor::findLinkAt(const QTextCursor &cur
         return link;
 
     const Snapshot snapshot = m_modelManager->snapshot();
-    DuiDocument::Ptr doc = snapshot.document(file()->fileName());
+    QmlDocument::Ptr doc = snapshot.document(file()->fileName());
     if (!doc)
         return link;
 
@@ -741,7 +741,7 @@ void ScriptEditor::contextMenuEvent(QContextMenuEvent *e)
 {
     QMenu *menu = createStandardContextMenu();
 
-    if (Core::ActionContainer *mcontext = Core::ICore::instance()->actionManager()->actionContainer(DuiEditor::Constants::M_CONTEXT)) {
+    if (Core::ActionContainer *mcontext = Core::ICore::instance()->actionManager()->actionContainer(QmlEditor::Constants::M_CONTEXT)) {
         QMenu *contextMenu = mcontext->menu();
         foreach (QAction *action, contextMenu->actions())
             menu->addAction(action);
@@ -765,4 +765,4 @@ void ScriptEditor::unCommentSelection()
 }
 
 } // namespace Internal
-} // namespace DuiEditor
+} // namespace QmlEditor
diff --git a/src/plugins/duieditor/duieditor.h b/src/plugins/qmleditor/qmleditor.h
similarity index 90%
rename from src/plugins/duieditor/duieditor.h
rename to src/plugins/qmleditor/qmleditor.h
index 1743e99528c42ac6a44e61acfa613e352087d532..0e78bdbd2e7bcd846d521e048788247c9ad9f934 100644
--- a/src/plugins/duieditor/duieditor.h
+++ b/src/plugins/qmleditor/qmleditor.h
@@ -27,14 +27,14 @@
 **
 **************************************************************************/
 
-#ifndef DUIDITORW_H
-#define DUIDITORW_H
+#ifndef QMLEDITORW_H
+#define QMLEDITORW_H
 
 #include <texteditor/basetexteditor.h>
 
 #include "qmljsastfwd_p.h"
 #include "qmljsengine_p.h"
-#include "duidocument.h"
+#include "qmldocument.h"
 
 QT_BEGIN_NAMESPACE
 class QComboBox;
@@ -45,13 +45,13 @@ namespace Core {
 class ICore;
 }
 
-namespace DuiEditor {
+namespace QmlEditor {
 
-class DuiModelManagerInterface;
+class QmlModelManagerInterface;
 
 namespace Internal {
 
-class DuiHighlighter;
+class QmlHighlighter;
 class ScriptEditor;
 
 class ScriptEditorEditable : public TextEditor::BaseTextEditorEditable
@@ -108,13 +108,13 @@ public:
 
     virtual void unCommentSelection();
 
-    DuiDocument::Ptr duiDocument() const { return m_document; }
+    QmlDocument::Ptr qmlDocument() const { return m_document; }
 
 public slots:
     virtual void setFontSettings(const TextEditor::FontSettings &);
 
 private slots:
-    void onDocumentUpdated(DuiDocument::Ptr doc);
+    void onDocumentUpdated(QmlDocument::Ptr doc);
 
     void updateDocument();
     void updateDocumentNow();
@@ -146,11 +146,11 @@ private:
     QStringList m_words;
     QMap<QString, QList<QmlJS::AST::SourceLocation> > m_ids; // ### use QMultiMap
     QList<QmlJS::DiagnosticMessage> m_diagnosticMessages;
-    DuiDocument::Ptr m_document;
-    DuiModelManagerInterface *m_modelManager;
+    QmlDocument::Ptr m_document;
+    QmlModelManagerInterface *m_modelManager;
 };
 
 } // namespace Internal
-} // namespace DuiEditor
+} // namespace QmlEditor
 
-#endif // DUIDITORW_H
+#endif // QMLEDITORW_H
diff --git a/src/plugins/qmleditor/qmleditor.pri b/src/plugins/qmleditor/qmleditor.pri
new file mode 100644
index 0000000000000000000000000000000000000000..0635392969412034d4ca5a1f8a49d4aaac12f49b
--- /dev/null
+++ b/src/plugins/qmleditor/qmleditor.pri
@@ -0,0 +1,3 @@
+include(qmleditor_dependencies.pri)
+
+LIBS *= -l$$qtLibraryTarget(QmlEditor)
diff --git a/src/plugins/qmleditor/qmleditor.pro b/src/plugins/qmleditor/qmleditor.pro
new file mode 100644
index 0000000000000000000000000000000000000000..1399b679e1e298d7a537a4a4d8038cbff08e7d25
--- /dev/null
+++ b/src/plugins/qmleditor/qmleditor.pro
@@ -0,0 +1,49 @@
+TEMPLATE = lib
+TARGET = QmlEditor
+include(../../qtcreatorplugin.pri)
+include(qmleditor_dependencies.pri)
+include(parser/parser.pri)
+include(rewriter/rewriter.pri)
+DEFINES += QMLEDITOR_LIBRARY \
+    QT_CREATOR
+INCLUDEPATH += parser \
+    rewriter
+HEADERS += qmleditor.h \
+    qmleditorfactory.h \
+    qmleditorplugin.h \
+    qmlhighlighter.h \
+    qmleditoractionhandler.h \
+    qmlcodecompletion.h \
+    qmleditorconstants.h \
+    qmlhoverhandler.h \
+    qmldocument.h \
+    qmlcompletionvisitor.h \
+    qmlmodelmanagerinterface.h \
+    qmleditor_global.h \
+    qmlmodelmanager.h \
+    qmlcodeformatter.h \
+    idcollector.h \
+    qmlexpressionundercursor.h \
+    qmllookupcontext.h \
+    qmlresolveexpression.h \
+    qmlsymbol.h \
+    qmlfilewizard.h
+SOURCES += qmleditor.cpp \
+    qmleditorfactory.cpp \
+    qmleditorplugin.cpp \
+    qmlhighlighter.cpp \
+    qmleditoractionhandler.cpp \
+    qmlcodecompletion.cpp \
+    qmlhoverhandler.cpp \
+    qmldocument.cpp \
+    qmlcompletionvisitor.cpp \
+    qmlmodelmanagerinterface.cpp \
+    qmlmodelmanager.cpp \
+    qmlcodeformatter.cpp \
+    idcollector.cpp \
+    qmlexpressionundercursor.cpp \
+    qmllookupcontext.cpp \
+    qmlresolveexpression.cpp \
+    qmlsymbol.cpp \
+    qmlfilewizard.cpp
+RESOURCES += qmleditor.qrc
diff --git a/src/plugins/qmleditor/qmleditor.qrc b/src/plugins/qmleditor/qmleditor.qrc
new file mode 100644
index 0000000000000000000000000000000000000000..b6eac04ae517e35cc2b89bf2fd64116404449e38
--- /dev/null
+++ b/src/plugins/qmleditor/qmleditor.qrc
@@ -0,0 +1,5 @@
+<RCC>
+    <qresource prefix="/qmleditor" >
+        <file>QmlEditor.mimetypes.xml</file>
+    </qresource>
+</RCC>
diff --git a/src/plugins/duieditor/duieditor_dependencies.pri b/src/plugins/qmleditor/qmleditor_dependencies.pri
similarity index 100%
rename from src/plugins/duieditor/duieditor_dependencies.pri
rename to src/plugins/qmleditor/qmleditor_dependencies.pri
diff --git a/src/plugins/qmleditor/qmleditor_global.h b/src/plugins/qmleditor/qmleditor_global.h
new file mode 100644
index 0000000000000000000000000000000000000000..95a6c5cb216351033475d3be28c8e97f0169683b
--- /dev/null
+++ b/src/plugins/qmleditor/qmleditor_global.h
@@ -0,0 +1,12 @@
+#ifndef QMLEDITOR_GLOBAL_H
+#define QMLEDITOR_GLOBAL_H
+
+#include <QtGlobal>
+
+#if defined(QMLEDITOR_LIBRARY)
+#  define QMLEDITOR_EXPORT Q_DECL_EXPORT
+#else
+#  define QMLEDITOR_EXPORT Q_DECL_IMPORT
+#endif
+
+#endif // QMLEDITOR_GLOBAL_H
diff --git a/src/plugins/duieditor/duieditoractionhandler.cpp b/src/plugins/qmleditor/qmleditoractionhandler.cpp
similarity index 83%
rename from src/plugins/duieditor/duieditoractionhandler.cpp
rename to src/plugins/qmleditor/qmleditoractionhandler.cpp
index de776d5a814882b9995fd33ea433d2e180c2a38f..45fc2f9d66a351866277296ec0830a320e5fa8e2 100644
--- a/src/plugins/duieditor/duieditoractionhandler.cpp
+++ b/src/plugins/qmleditor/qmleditoractionhandler.cpp
@@ -27,9 +27,9 @@
 **
 **************************************************************************/
 
-#include "duieditoractionhandler.h"
-#include "duieditorconstants.h"
-#include "duieditor.h"
+#include "qmleditoractionhandler.h"
+#include "qmleditorconstants.h"
+#include "qmleditor.h"
 
 #include <coreplugin/icore.h>
 #include <coreplugin/actionmanager/actionmanager.h>
@@ -39,20 +39,20 @@
 #include <QtGui/QMainWindow>
 #include <QtGui/QMessageBox>
 
-namespace DuiEditor {
+namespace QmlEditor {
 namespace Internal {
 
-DuiEditorActionHandler::DuiEditorActionHandler()
-  : TextEditor::TextEditorActionHandler(QLatin1String(DuiEditor::Constants::C_DUIEDITOR),
+QmlEditorActionHandler::QmlEditorActionHandler()
+  : TextEditor::TextEditorActionHandler(QLatin1String(QmlEditor::Constants::C_QMLEDITOR),
                                         Format)
 {
 }
 
-void DuiEditorActionHandler::createActions()
+void QmlEditorActionHandler::createActions()
 {
     TextEditor::TextEditorActionHandler::createActions();
 }
 
 
 } // namespace Internal
-} // namespace DuiEditor
+} // namespace QmlEditor
diff --git a/src/plugins/duieditor/duieditoractionhandler.h b/src/plugins/qmleditor/qmleditoractionhandler.h
similarity index 85%
rename from src/plugins/duieditor/duieditoractionhandler.h
rename to src/plugins/qmleditor/qmleditoractionhandler.h
index adc67dba65a77ec520d6c2bfe006fdf9015c871a..49b9c320ea138d716027a4180a194727e6e9651c 100644
--- a/src/plugins/duieditor/duieditoractionhandler.h
+++ b/src/plugins/qmleditor/qmleditoractionhandler.h
@@ -27,25 +27,25 @@
 **
 **************************************************************************/
 
-#ifndef DUIDITORACTIONHANDLER_H
-#define DUIDITORACTIONHANDLER_H
+#ifndef QMLDITORACTIONHANDLER_H
+#define QMLDITORACTIONHANDLER_H
 
 #include <texteditor/texteditoractionhandler.h>
 
-namespace DuiEditor {
+namespace QmlEditor {
 namespace Internal {
 
-class DuiEditorActionHandler : public TextEditor::TextEditorActionHandler
+class QmlEditorActionHandler : public TextEditor::TextEditorActionHandler
 {
     Q_OBJECT
 
 public:
-    DuiEditorActionHandler();
+    QmlEditorActionHandler();
 
     void createActions();
 };
 
 } // namespace Internal
-} // namespace DuiEditor
+} // namespace QmlEditor
 
-#endif // DUIDITORACTIONHANDLER_H
+#endif // QMLDITORACTIONHANDLER_H
diff --git a/src/plugins/duieditor/duieditorconstants.h b/src/plugins/qmleditor/qmleditorconstants.h
similarity index 75%
rename from src/plugins/duieditor/duieditorconstants.h
rename to src/plugins/qmleditor/qmleditorconstants.h
index a8b8d60b11d0f261a4d3ab6d7fe1c71e8fed1a32..2fc8919ddd78050b0073bc16b8eefe2945b29240 100644
--- a/src/plugins/duieditor/duieditorconstants.h
+++ b/src/plugins/qmleditor/qmleditorconstants.h
@@ -27,20 +27,20 @@
 **
 **************************************************************************/
 
-#ifndef DUIEDITOR_CONSTANTS_H
-#define DUIEDITOR_CONSTANTS_H
+#ifndef QMLEDITOR_CONSTANTS_H
+#define QMLEDITOR_CONSTANTS_H
 
-namespace DuiEditor {
+namespace QmlEditor {
 namespace Constants {
 
-const char * const M_CONTEXT = "DUI Editor.ContextMenu";
-const char * const RUN_SEP = "DuiEditor.Run.Separator";
-const char * const C_DUIEDITOR = "QML Editor";
-const char * const TASK_INDEX = "DuiEditor.TaskIndex";
+const char * const M_CONTEXT = "QML Editor.ContextMenu";
+const char * const RUN_SEP = "QmlEditor.Run.Separator";
+const char * const C_QMLEDITOR = "QML Editor";
+const char * const TASK_INDEX = "QmlEditor.TaskIndex";
 
-const char * const DUIEDITOR_MIMETYPE = "application/x-dui";
+const char * const QMLEDITOR_MIMETYPE = "application/x-qml";
 
 } // namespace Constants
-} // namespace DuiEditor
+} // namespace QmlEditor
 
-#endif // DUIEDITOR_CONSTANTS_H
+#endif // QMLEDITOR_CONSTANTS_H
diff --git a/src/plugins/duieditor/duieditorfactory.cpp b/src/plugins/qmleditor/qmleditorfactory.cpp
similarity index 68%
rename from src/plugins/duieditor/duieditorfactory.cpp
rename to src/plugins/qmleditor/qmleditorfactory.cpp
index cfbe6757cd5c296272f774f78afe8bd8483d8318..2b8173404d475ae754e8e39d8aa13dc43f673bde 100644
--- a/src/plugins/duieditor/duieditorfactory.cpp
+++ b/src/plugins/qmleditor/qmleditorfactory.cpp
@@ -27,57 +27,57 @@
 **
 **************************************************************************/
 
-#include "duieditorfactory.h"
-#include "duieditor.h"
-#include "duieditoractionhandler.h"
-#include "duieditorconstants.h"
-#include "duieditorplugin.h"
+#include "qmleditorfactory.h"
+#include "qmleditor.h"
+#include "qmleditoractionhandler.h"
+#include "qmleditorconstants.h"
+#include "qmleditorplugin.h"
 
 #include <coreplugin/editormanager/editormanager.h>
 
 #include <QtCore/QFileInfo>
 #include <QtCore/QDebug>
 
-using namespace DuiEditor::Internal;
-using namespace DuiEditor::Constants;
+using namespace QmlEditor::Internal;
+using namespace QmlEditor::Constants;
 
-DuiEditorFactory::DuiEditorFactory(const Context &context, QObject *parent)
+QmlEditorFactory::QmlEditorFactory(const Context &context, QObject *parent)
   : Core::IEditorFactory(parent),
-    m_kind(QLatin1String(C_DUIEDITOR)),
-    m_mimeTypes(QLatin1String(DuiEditor::Constants::DUIEDITOR_MIMETYPE)),
+    m_kind(QLatin1String(C_QMLEDITOR)),
+    m_mimeTypes(QLatin1String(QmlEditor::Constants::QMLEDITOR_MIMETYPE)),
     m_context(context),
-    m_actionHandler(new DuiEditorActionHandler)
+    m_actionHandler(new QmlEditorActionHandler)
 {
 }
 
-DuiEditorFactory::~DuiEditorFactory()
+QmlEditorFactory::~QmlEditorFactory()
 {
     delete m_actionHandler;
 }
 
-QString DuiEditorFactory::kind() const
+QString QmlEditorFactory::kind() const
 {
     return m_kind;
 }
 
-Core::IFile *DuiEditorFactory::open(const QString &fileName)
+Core::IFile *QmlEditorFactory::open(const QString &fileName)
 {
     Core::IEditor *iface = Core::EditorManager::instance()->openEditor(fileName, kind());
     if (!iface) {
-        qWarning() << "DuiEditorFactory::open: openEditor failed for " << fileName;
+        qWarning() << "QmlEditorFactory::open: openEditor failed for " << fileName;
         return 0;
     }
     return iface->file();
 }
 
-Core::IEditor *DuiEditorFactory::createEditor(QWidget *parent)
+Core::IEditor *QmlEditorFactory::createEditor(QWidget *parent)
 {
     ScriptEditor *rc = new ScriptEditor(m_context, parent);
-    DuiEditorPlugin::instance()->initializeEditor(rc);
+    QmlEditorPlugin::instance()->initializeEditor(rc);
     return rc->editableInterface();
 }
 
-QStringList DuiEditorFactory::mimeTypes() const
+QStringList QmlEditorFactory::mimeTypes() const
 {
     return m_mimeTypes;
 }
diff --git a/src/plugins/duieditor/duieditorfactory.h b/src/plugins/qmleditor/qmleditorfactory.h
similarity index 85%
rename from src/plugins/duieditor/duieditorfactory.h
rename to src/plugins/qmleditor/qmleditorfactory.h
index d72cc8d7bfaeb985f90d94e5cfcb215726766541..af178e68c91e28000847a65f05cc84c7c4a97095 100644
--- a/src/plugins/duieditor/duieditorfactory.h
+++ b/src/plugins/qmleditor/qmleditorfactory.h
@@ -27,8 +27,8 @@
 **
 **************************************************************************/
 
-#ifndef RDUIEDITORFACTORY_H
-#define RDUIEDITORFACTORY_H
+#ifndef QMLEDITORFACTORY_H
+#define QMLEDITORFACTORY_H
 
 #include <coreplugin/editormanager/ieditorfactory.h>
 
@@ -38,20 +38,20 @@ namespace TextEditor {
 class TextEditorActionHandler;
 }
 
-namespace DuiEditor {
+namespace QmlEditor {
 namespace Internal {
 
-class DuiEditorActionHandler;
+class QmlEditorActionHandler;
 
-class DuiEditorFactory : public Core::IEditorFactory
+class QmlEditorFactory : public Core::IEditorFactory
 {
     Q_OBJECT
 
 public:
     typedef QList<int> Context;
 
-    DuiEditorFactory(const Context &context, QObject *parent);
-    ~DuiEditorFactory();
+    QmlEditorFactory(const Context &context, QObject *parent);
+    ~QmlEditorFactory();
 
     virtual QStringList mimeTypes() const;
     // IEditorFactory
@@ -68,6 +68,6 @@ private:
 };
 
 } // namespace Internal
-} // namespace DuiEditor
+} // namespace QmlEditor
 
-#endif // RDUIEDITORFACTORY_H
+#endif // QMLEDITORFACTORY_H
diff --git a/src/plugins/duieditor/duieditorplugin.cpp b/src/plugins/qmleditor/qmleditorplugin.cpp
similarity index 78%
rename from src/plugins/duieditor/duieditorplugin.cpp
rename to src/plugins/qmleditor/qmleditorplugin.cpp
index c53d16f89a094e68825e9349f1b8900ff42980be..c2cfc50db3fdf64e16325054565035fe5da58019 100644
--- a/src/plugins/duieditor/duieditorplugin.cpp
+++ b/src/plugins/qmleditor/qmleditorplugin.cpp
@@ -27,15 +27,15 @@
 **
 **************************************************************************/
 
-#include "duieditorplugin.h"
+#include "qmleditorplugin.h"
 
 #include "qscripthighlighter.h"
-#include "duieditor.h"
-#include "duieditorconstants.h"
-#include "duieditorfactory.h"
-#include "duicodecompletion.h"
-#include "duihoverhandler.h"
-#include "duimodelmanager.h"
+#include "qmleditor.h"
+#include "qmleditorconstants.h"
+#include "qmleditorfactory.h"
+#include "qmlcodecompletion.h"
+#include "qmlhoverhandler.h"
+#include "qmlmodelmanager.h"
 #include "qmlfilewizard.h"
 
 #include <coreplugin/icore.h>
@@ -58,13 +58,13 @@
 #include <QtCore/QSettings>
 #include <QtGui/QAction>
 
-using namespace DuiEditor;
-using namespace DuiEditor::Internal;
-using namespace DuiEditor::Constants;
+using namespace QmlEditor;
+using namespace QmlEditor::Internal;
+using namespace QmlEditor::Constants;
 
-DuiEditorPlugin *DuiEditorPlugin::m_instance = 0;
+QmlEditorPlugin *QmlEditorPlugin::m_instance = 0;
 
-DuiEditorPlugin::DuiEditorPlugin() :
+QmlEditorPlugin::QmlEditorPlugin() :
         m_modelManager(0),
     m_wizard(0),
     m_editor(0),
@@ -74,31 +74,31 @@ DuiEditorPlugin::DuiEditorPlugin() :
     m_instance = this;
 }
 
-DuiEditorPlugin::~DuiEditorPlugin()
+QmlEditorPlugin::~QmlEditorPlugin()
 {
     removeObject(m_editor);
     delete m_actionHandler;
     m_instance = 0;
 }
 
-bool DuiEditorPlugin::initialize(const QStringList & /*arguments*/, QString *error_message)
+bool QmlEditorPlugin::initialize(const QStringList & /*arguments*/, QString *error_message)
 {
     typedef SharedTools::QScriptHighlighter QScriptHighlighter;
 
     Core::ICore *core = Core::ICore::instance();
-    if (!core->mimeDatabase()->addMimeTypes(QLatin1String(":/duieditor/DuiEditor.mimetypes.xml"), error_message))
+    if (!core->mimeDatabase()->addMimeTypes(QLatin1String(":/qmleditor/QmlEditor.mimetypes.xml"), error_message))
         return false;
 
-    m_modelManager = new DuiModelManager(this);
+    m_modelManager = new QmlModelManager(this);
     addAutoReleasedObject(m_modelManager);
 
-    m_scriptcontext << core->uniqueIDManager()->uniqueIdentifier(DuiEditor::Constants::C_DUIEDITOR);
+    m_scriptcontext << core->uniqueIDManager()->uniqueIdentifier(QmlEditor::Constants::C_QMLEDITOR);
     m_context = m_scriptcontext;
     m_context << core->uniqueIDManager()->uniqueIdentifier(TextEditor::Constants::C_TEXTEDITOR);
 
     registerActions();
 
-    m_editor = new DuiEditorFactory(m_context, this);
+    m_editor = new QmlEditorFactory(m_context, this);
     addObject(m_editor);
 
     Core::BaseFileWizardParameters wizardParameters(Core::IWizard::FileWizard);
@@ -108,16 +108,16 @@ bool DuiEditorPlugin::initialize(const QStringList & /*arguments*/, QString *err
     wizardParameters.setName(tr("Qt QML File"));
     addAutoReleasedObject(new QmlFileWizard(wizardParameters, core));
 
-    m_actionHandler = new TextEditor::TextEditorActionHandler(DuiEditor::Constants::C_DUIEDITOR,
+    m_actionHandler = new TextEditor::TextEditorActionHandler(QmlEditor::Constants::C_QMLEDITOR,
           TextEditor::TextEditorActionHandler::Format
         | TextEditor::TextEditorActionHandler::UnCommentSelection
         | TextEditor::TextEditorActionHandler::UnCollapseAll);
     m_actionHandler->initializeActions();
 
-    m_completion = new DuiCodeCompletion();
+    m_completion = new QmlCodeCompletion();
     addAutoReleasedObject(m_completion);
 
-    addAutoReleasedObject(new DuiHoverHandler());
+    addAutoReleasedObject(new QmlHoverHandler());
 
     // Restore settings
     QSettings *settings = Core::ICore::instance()->settings();
@@ -133,11 +133,11 @@ bool DuiEditorPlugin::initialize(const QStringList & /*arguments*/, QString *err
     return true;
 }
 
-void DuiEditorPlugin::extensionsInitialized()
+void QmlEditorPlugin::extensionsInitialized()
 {
 }
 
-void DuiEditorPlugin::initializeEditor(DuiEditor::Internal::ScriptEditor *editor)
+void QmlEditorPlugin::initializeEditor(QmlEditor::Internal::ScriptEditor *editor)
 {
     QTC_ASSERT(m_instance, /**/);
 
@@ -150,8 +150,8 @@ void DuiEditorPlugin::initializeEditor(DuiEditor::Internal::ScriptEditor *editor
             TextEditor::Internal::CompletionSupport::instance(), SLOT(autoComplete(ITextEditable*, bool)));
 }
 
-void DuiEditorPlugin::registerActions()
+void QmlEditorPlugin::registerActions()
 {
 }
 
-Q_EXPORT_PLUGIN(DuiEditorPlugin)
+Q_EXPORT_PLUGIN(QmlEditorPlugin)
diff --git a/src/plugins/duieditor/duieditorplugin.h b/src/plugins/qmleditor/qmleditorplugin.h
similarity index 78%
rename from src/plugins/duieditor/duieditorplugin.h
rename to src/plugins/qmleditor/qmleditorplugin.h
index 54c947040ef84dcf3949702768b9f0e48d340615..85a15e22fa183083ef7e0ce835e93bf622d8650a 100644
--- a/src/plugins/duieditor/duieditorplugin.h
+++ b/src/plugins/qmleditor/qmleditorplugin.h
@@ -27,8 +27,8 @@
 **
 **************************************************************************/
 
-#ifndef DUIEDITORPLUGIN_H
-#define DUIEDITORPLUGIN_H
+#ifndef QMLEDITORPLUGIN_H
+#define QMLEDITORPLUGIN_H
 
 #include <extensionsystem/iplugin.h>
 
@@ -36,30 +36,30 @@ namespace TextEditor {
 class TextEditorActionHandler;
 } // namespace TextEditor
 
-namespace DuiEditor {
+namespace QmlEditor {
 
-class DuiModelManagerInterface;
+class QmlModelManagerInterface;
 class QmlFileWizard;
 
 namespace Internal {
 
-class DuiEditorFactory;
-class DuiCodeCompletion;
+class QmlEditorFactory;
+class QmlCodeCompletion;
 class ScriptEditor;
 
-class DuiEditorPlugin : public ExtensionSystem::IPlugin
+class QmlEditorPlugin : public ExtensionSystem::IPlugin
 {
     Q_OBJECT
 
 public:
-    DuiEditorPlugin();
-    virtual ~DuiEditorPlugin();
+    QmlEditorPlugin();
+    virtual ~QmlEditorPlugin();
 
     // IPlugin
     bool initialize(const QStringList &arguments, QString *errorMessage = 0);
     void extensionsInitialized();
 
-    static DuiEditorPlugin *instance()
+    static QmlEditorPlugin *instance()
     { return m_instance; }
 
     void initializeEditor(ScriptEditor *editor);
@@ -67,20 +67,20 @@ public:
 private:
     void registerActions();
 
-    static DuiEditorPlugin *m_instance;
+    static QmlEditorPlugin *m_instance;
 
     typedef QList<int> Context;
     Context m_context;
     Context m_scriptcontext;
 
-    DuiModelManagerInterface *m_modelManager;
+    QmlModelManagerInterface *m_modelManager;
     QmlFileWizard *m_wizard;
-    DuiEditorFactory *m_editor;
+    QmlEditorFactory *m_editor;
     TextEditor::TextEditorActionHandler *m_actionHandler;
-    DuiCodeCompletion *m_completion;
+    QmlCodeCompletion *m_completion;
 };
 
 } // namespace Internal
-} // namespace DuiEditor
+} // namespace QmlEditor
 
-#endif // DUIEDITORPLUGIN_H
+#endif // QMLEDITORPLUGIN_H
diff --git a/src/plugins/duieditor/qmlexpressionundercursor.cpp b/src/plugins/qmleditor/qmlexpressionundercursor.cpp
similarity index 97%
rename from src/plugins/duieditor/qmlexpressionundercursor.cpp
rename to src/plugins/qmleditor/qmlexpressionundercursor.cpp
index 463f93ce61c211f09a6b5feae97a2edeb7afa7a3..133ab2bac6fb7a4bf8e16c231b8457469a745538 100644
--- a/src/plugins/duieditor/qmlexpressionundercursor.cpp
+++ b/src/plugins/qmleditor/qmlexpressionundercursor.cpp
@@ -3,8 +3,8 @@
 
 #include "qmlexpressionundercursor.h"
 
-using namespace DuiEditor;
-using namespace DuiEditor::Internal;
+using namespace QmlEditor;
+using namespace QmlEditor::Internal;
 using namespace QmlJS;
 using namespace QmlJS::AST;
 
diff --git a/src/plugins/duieditor/qmlexpressionundercursor.h b/src/plugins/qmleditor/qmlexpressionundercursor.h
similarity index 96%
rename from src/plugins/duieditor/qmlexpressionundercursor.h
rename to src/plugins/qmleditor/qmlexpressionundercursor.h
index 4642e54e3b010fa1a54074bd6a9af1b1aed743e0..a891dc8968fc441db6741231f5ab7c094664234b 100644
--- a/src/plugins/duieditor/qmlexpressionundercursor.h
+++ b/src/plugins/qmleditor/qmlexpressionundercursor.h
@@ -6,7 +6,7 @@
 
 #include "qmljsastvisitor_p.h"
 
-namespace DuiEditor {
+namespace QmlEditor {
 namespace Internal {
 
 class QmlExpressionUnderCursor: protected QmlJS::AST::Visitor
@@ -51,6 +51,6 @@ private:
 };
 
 } // namespace Internal
-} // namespace DuiEditor
+} // namespace QmlEditor
 
 #endif // QMLEXPRESSIONUNDERCURSOR_H
diff --git a/src/plugins/duieditor/qmlfilewizard.cpp b/src/plugins/qmleditor/qmlfilewizard.cpp
similarity index 87%
rename from src/plugins/duieditor/qmlfilewizard.cpp
rename to src/plugins/qmleditor/qmlfilewizard.cpp
index 1529908ce72fe515e796bc49250d0aa29d3bb3a4..ae6a845f49d3572197c89ecc7f8b1114eda126ce 100644
--- a/src/plugins/duieditor/qmlfilewizard.cpp
+++ b/src/plugins/qmleditor/qmlfilewizard.cpp
@@ -1,10 +1,10 @@
-#include "duieditorconstants.h"
+#include "qmleditorconstants.h"
 #include "qmlfilewizard.h"
 
 #include <QtCore/QFileInfo>
 #include <QtCore/QTextStream>
 
-using namespace DuiEditor;
+using namespace QmlEditor;
 
 QmlFileWizard::QmlFileWizard(const BaseFileWizardParameters &parameters,
                              QObject *parent):
@@ -17,11 +17,11 @@ Core::GeneratedFiles QmlFileWizard::generateFilesFromPath(const QString &path,
                                                           QString * /*errorMessage*/) const
 
 {
-    const QString mimeType = QLatin1String(Constants::DUIEDITOR_MIMETYPE);
+    const QString mimeType = QLatin1String(Constants::QMLEDITOR_MIMETYPE);
     const QString fileName = Core::BaseFileWizard::buildFileName(path, name, preferredSuffix(mimeType));
 
     Core::GeneratedFile file(fileName);
-    file.setEditorKind(QLatin1String(Constants::C_DUIEDITOR));
+    file.setEditorKind(QLatin1String(Constants::C_QMLEDITOR));
     file.setContents(fileContents(fileName));
 
     return Core::GeneratedFiles() << file;
diff --git a/src/plugins/duieditor/qmlfilewizard.h b/src/plugins/qmleditor/qmlfilewizard.h
similarity index 93%
rename from src/plugins/duieditor/qmlfilewizard.h
rename to src/plugins/qmleditor/qmlfilewizard.h
index cb040bceaa797fc4834ff13578e8e8f4c45fd648..3f742698ead4b9c04049c20ffab36be95a81c3f6 100644
--- a/src/plugins/duieditor/qmlfilewizard.h
+++ b/src/plugins/qmleditor/qmlfilewizard.h
@@ -3,7 +3,7 @@
 
 #include <coreplugin/basefilewizard.h>
 
-namespace DuiEditor {
+namespace QmlEditor {
 
 class QmlFileWizard: public Core::StandardFileWizard
 {
@@ -24,6 +24,6 @@ protected:
                                                QString *errorMessage) const;
 };
 
-} // namespace DuiEditor
+} // namespace QmlEditor
 
 #endif // QMLFILEWIZARD_H
diff --git a/src/plugins/duieditor/duihighlighter.cpp b/src/plugins/qmleditor/qmlhighlighter.cpp
similarity index 86%
rename from src/plugins/duieditor/duihighlighter.cpp
rename to src/plugins/qmleditor/qmlhighlighter.cpp
index caba058a0874ebcf469d2cc5c23e2ef3c6aa0061..fa9bb7ace1213546c325d0a3d42798cc8d442011 100644
--- a/src/plugins/duieditor/duihighlighter.cpp
+++ b/src/plugins/qmleditor/qmlhighlighter.cpp
@@ -27,26 +27,26 @@
 **
 **************************************************************************/
 
-#include "duihighlighter.h"
+#include "qmlhighlighter.h"
 
 #include <utils/qtcassert.h>
 
-using namespace DuiEditor;
-using namespace DuiEditor::Internal;
+using namespace QmlEditor;
+using namespace QmlEditor::Internal;
 
-DuiHighlighter::DuiHighlighter(QTextDocument *parent) :
+QmlHighlighter::QmlHighlighter(QTextDocument *parent) :
      SharedTools::QScriptHighlighter(true, parent)
 {
     m_currentBlockParentheses.reserve(20);
     m_braceDepth = 0;
 
-    QSet<QString> duiKeywords(keywords());
-    duiKeywords << QLatin1String("property");
-    duiKeywords << QLatin1String("signal");
-    m_scanner.setKeywords(duiKeywords);
+    QSet<QString> qmlKeywords(keywords());
+    qmlKeywords << QLatin1String("property");
+    qmlKeywords << QLatin1String("signal");
+    m_scanner.setKeywords(qmlKeywords);
 }
 
-int DuiHighlighter::onBlockStart()
+int QmlHighlighter::onBlockStart()
 {
     m_currentBlockParentheses.clear();
     m_braceDepth = 0;
@@ -61,21 +61,21 @@ int DuiHighlighter::onBlockStart()
     return state;
 }
 
-void DuiHighlighter::onOpeningParenthesis(QChar parenthesis, int pos)
+void QmlHighlighter::onOpeningParenthesis(QChar parenthesis, int pos)
 {
     if (parenthesis == QLatin1Char('{'))
         ++m_braceDepth;
      m_currentBlockParentheses.push_back(Parenthesis(Parenthesis::Opened, parenthesis, pos));
 }
 
-void DuiHighlighter::onClosingParenthesis(QChar parenthesis, int pos)
+void QmlHighlighter::onClosingParenthesis(QChar parenthesis, int pos)
 {
     if (parenthesis == QLatin1Char('}'))
         --m_braceDepth;
     m_currentBlockParentheses.push_back(Parenthesis(Parenthesis::Closed, parenthesis, pos));
 }
 
-void DuiHighlighter::onBlockEnd(int state, int firstNonSpace)
+void QmlHighlighter::onBlockEnd(int state, int firstNonSpace)
 {
     typedef TextEditor::TextBlockUserData TextEditorBlockData;
 
diff --git a/src/plugins/duieditor/duihighlighter.h b/src/plugins/qmleditor/qmlhighlighter.h
similarity index 88%
rename from src/plugins/duieditor/duihighlighter.h
rename to src/plugins/qmleditor/qmlhighlighter.h
index 62ef1c184337f8859e69fb9771d552f7a12c0699..8c7df6c11d5035f09eb7ef407c9a222d04b68ff2 100644
--- a/src/plugins/duieditor/duihighlighter.h
+++ b/src/plugins/qmleditor/qmlhighlighter.h
@@ -27,24 +27,24 @@
 **
 **************************************************************************/
 
-#ifndef DUISYNTAXHIGHLIGHTER_H
-#define DUISYNTAXHIGHLIGHTER_H
+#ifndef QMLSYNTAXHIGHLIGHTER_H
+#define QMLSYNTAXHIGHLIGHTER_H
 
 #include "qscripthighlighter.h"
 #include <texteditor/basetexteditor.h>
 
-namespace DuiEditor {
+namespace QmlEditor {
 namespace Internal {
 
 // Highlighter for Scripts that stores
 // the parentheses encountered in the block data
 // for parentheses matching to work.
 
-class DuiHighlighter : public SharedTools::QScriptHighlighter
+class QmlHighlighter : public SharedTools::QScriptHighlighter
 {
     Q_OBJECT
 public:
-    DuiHighlighter(QTextDocument *parent = 0);
+    QmlHighlighter(QTextDocument *parent = 0);
 
 private:
     virtual int onBlockStart();
@@ -59,6 +59,6 @@ private:
 };
 
 } // namespace Internal
-} // namespace DuiEditor
+} // namespace QmlEditor
 
-#endif // DUISYNTAXHIGHLIGHTER_H
+#endif // QMLSYNTAXHIGHLIGHTER_H
diff --git a/src/plugins/duieditor/duihoverhandler.cpp b/src/plugins/qmleditor/qmlhoverhandler.cpp
similarity index 85%
rename from src/plugins/duieditor/duihoverhandler.cpp
rename to src/plugins/qmleditor/qmlhoverhandler.cpp
index bbdec757a8602b33ada77553ee6c0def57c3ef1f..890a4167fec476c3f13ae0e13c680e223cd7fa51 100644
--- a/src/plugins/duieditor/duihoverhandler.cpp
+++ b/src/plugins/qmleditor/qmlhoverhandler.cpp
@@ -27,8 +27,8 @@
 **
 **************************************************************************/
 
-#include "duihoverhandler.h"
-#include "duieditor.h"
+#include "qmlhoverhandler.h"
+#include "qmleditor.h"
 
 #include <coreplugin/icore.h>
 #include <coreplugin/uniqueidmanager.h>
@@ -47,10 +47,10 @@
 #include <QtGui/QTextBlock>
 #include <QtHelp/QHelpEngineCore>
 
-using namespace DuiEditor::Internal;
+using namespace QmlEditor::Internal;
 using namespace Core;
 
-DuiHoverHandler::DuiHoverHandler(QObject *parent)
+QmlHoverHandler::QmlHoverHandler(QObject *parent)
     : QObject(parent)
 {
     ICore *core = ICore::instance();
@@ -60,20 +60,20 @@ DuiHoverHandler::DuiHoverHandler(QObject *parent)
             this, SLOT(editorOpened(Core::IEditor *)));
 }
 
-void DuiHoverHandler::editorOpened(IEditor *editor)
+void QmlHoverHandler::editorOpened(IEditor *editor)
 {
-    ScriptEditorEditable *duiEditor = qobject_cast<ScriptEditorEditable *>(editor);
-    if (!duiEditor)
+    ScriptEditorEditable *qmlEditor = qobject_cast<ScriptEditorEditable *>(editor);
+    if (!qmlEditor)
         return;
 
-    connect(duiEditor, SIGNAL(tooltipRequested(TextEditor::ITextEditor*, QPoint, int)),
+    connect(qmlEditor, SIGNAL(tooltipRequested(TextEditor::ITextEditor*, QPoint, int)),
             this, SLOT(showToolTip(TextEditor::ITextEditor*, QPoint, int)));
 
-    connect(duiEditor, SIGNAL(contextHelpIdRequested(TextEditor::ITextEditor*, int)),
+    connect(qmlEditor, SIGNAL(contextHelpIdRequested(TextEditor::ITextEditor*, int)),
             this, SLOT(updateContextHelpId(TextEditor::ITextEditor*, int)));
 }
 
-void DuiHoverHandler::showToolTip(TextEditor::ITextEditor *editor, const QPoint &point, int pos)
+void QmlHoverHandler::showToolTip(TextEditor::ITextEditor *editor, const QPoint &point, int pos)
 {
     if (! editor)
         return;
@@ -114,7 +114,7 @@ void DuiHoverHandler::showToolTip(TextEditor::ITextEditor *editor, const QPoint
     }
 }
 
-void DuiHoverHandler::updateContextHelpId(TextEditor::ITextEditor *, int)
+void QmlHoverHandler::updateContextHelpId(TextEditor::ITextEditor *, int)
 {
 }
 
diff --git a/src/plugins/duieditor/duihoverhandler.h b/src/plugins/qmleditor/qmlhoverhandler.h
similarity index 89%
rename from src/plugins/duieditor/duihoverhandler.h
rename to src/plugins/qmleditor/qmlhoverhandler.h
index 49bd80165f9396a7a54aec5d9a927b17346f5750..13cca4a57a0dc3b6bdd8007d610ec34b7baf3e06 100644
--- a/src/plugins/duieditor/duihoverhandler.h
+++ b/src/plugins/qmleditor/qmlhoverhandler.h
@@ -27,8 +27,8 @@
 **
 **************************************************************************/
 
-#ifndef DUIHOVERHANDLER_H
-#define DUIHOVERHANDLER_H
+#ifndef QMLHOVERHANDLER_H
+#define QMLHOVERHANDLER_H
 
 #include <QtCore/QObject>
 
@@ -44,15 +44,15 @@ namespace TextEditor {
 class ITextEditor;
 }
 
-namespace DuiEditor {
+namespace QmlEditor {
 namespace Internal {
 
-class DuiHoverHandler : public QObject
+class QmlHoverHandler : public QObject
 {
     Q_OBJECT
 
 public:
-    DuiHoverHandler(QObject *parent = 0);
+    QmlHoverHandler(QObject *parent = 0);
 
 public slots:
     void showToolTip(TextEditor::ITextEditor *editor, const QPoint &point, int pos);
@@ -66,6 +66,6 @@ private:
 };
 
 } // namespace Internal
-} // namespace DuiEditor
+} // namespace QmlEditor
 
-#endif // DUIHOVERHANDLER_H
+#endif // QMLHOVERHANDLER_H
diff --git a/src/plugins/duieditor/qmllookupcontext.cpp b/src/plugins/qmleditor/qmllookupcontext.cpp
similarity index 92%
rename from src/plugins/duieditor/qmllookupcontext.cpp
rename to src/plugins/qmleditor/qmllookupcontext.cpp
index 83708c9834993d7d183105169feb1b2a46de8af5..e3fb7757c9373fa6d86929359dd940621d307976 100644
--- a/src/plugins/duieditor/qmllookupcontext.cpp
+++ b/src/plugins/qmleditor/qmllookupcontext.cpp
@@ -5,13 +5,13 @@
 #include "qmllookupcontext.h"
 #include "qmlresolveexpression.h"
 
-using namespace DuiEditor;
-using namespace DuiEditor::Internal;
+using namespace QmlEditor;
+using namespace QmlEditor::Internal;
 using namespace QmlJS;
 using namespace QmlJS::AST;
 
 QmlLookupContext::QmlLookupContext(const QStack<QmlJS::AST::Node *> &scopes,
-                                   const DuiDocument::Ptr &doc,
+                                   const QmlDocument::Ptr &doc,
                                    const Snapshot &snapshot):
         _scopes(scopes),
         _doc(doc),
@@ -44,7 +44,7 @@ QmlSymbol *QmlLookupContext::resolve(const QString &name)
     }
 
     // look at the ids.
-    const DuiDocument::IdTable ids = _doc->ids();
+    const QmlDocument::IdTable ids = _doc->ids();
 
     if (ids.contains(name))
         return ids[name];
@@ -62,7 +62,7 @@ QmlSymbol *QmlLookupContext::createSymbol(const QString &fileName, QmlJS::AST::U
 QmlSymbol *QmlLookupContext::resolveType(const QString &name, const QString &fileName)
 {
     // TODO: handle import-as.
-    DuiDocument::Ptr document = _snapshot[fileName];
+    QmlDocument::Ptr document = _snapshot[fileName];
     if (document.isNull())
         return 0;
 
@@ -84,9 +84,9 @@ QmlSymbol *QmlLookupContext::resolveType(const QString &name, const QString &fil
 
         const QString path = import->fileName->asString();
 
-        const QMap<QString, DuiDocument::Ptr> importedTypes = _snapshot.componentsDefinedByImportedDocuments(document, path);
+        const QMap<QString, QmlDocument::Ptr> importedTypes = _snapshot.componentsDefinedByImportedDocuments(document, path);
         if (importedTypes.contains(name)) {
-            DuiDocument::Ptr importedDoc = importedTypes.value(name);
+            QmlDocument::Ptr importedDoc = importedTypes.value(name);
 
             UiProgram *importedProgram = importedDoc->program();
             if (importedProgram && importedProgram->members && importedProgram->members->member)
@@ -194,8 +194,8 @@ QList<QmlSymbol*> QmlLookupContext::visibleTypes()
 
         // TODO: handle "import as".
 
-        const QMap<QString, DuiDocument::Ptr> types = _snapshot.componentsDefinedByImportedDocuments(_doc, path);
-        foreach (const DuiDocument::Ptr typeDoc, types) {
+        const QMap<QString, QmlDocument::Ptr> types = _snapshot.componentsDefinedByImportedDocuments(_doc, path);
+        foreach (const QmlDocument::Ptr typeDoc, types) {
             UiProgram *typeProgram = typeDoc->program();
 
             if (typeProgram && typeProgram->members && typeProgram->members->member) {
diff --git a/src/plugins/duieditor/qmllookupcontext.h b/src/plugins/qmleditor/qmllookupcontext.h
similarity index 87%
rename from src/plugins/duieditor/qmllookupcontext.h
rename to src/plugins/qmleditor/qmllookupcontext.h
index bf3817a0b689b66ff5b486749db67ae270bbd320..80635c03937dc716b1e0c0fb6898c59742103e7c 100644
--- a/src/plugins/duieditor/qmllookupcontext.h
+++ b/src/plugins/qmleditor/qmllookupcontext.h
@@ -3,18 +3,18 @@
 
 #include <QStack>
 
-#include "duidocument.h"
+#include "qmldocument.h"
 #include "qmljsastvisitor_p.h"
 #include "qmlsymbol.h"
 
-namespace DuiEditor {
+namespace QmlEditor {
 namespace Internal {
 
 class QmlLookupContext
 {
 public:
     QmlLookupContext(const QStack<QmlJS::AST::Node *> &scopes,
-                     const DuiDocument::Ptr &doc,
+                     const QmlDocument::Ptr &doc,
                      const Snapshot &snapshot);
     ~QmlLookupContext();
 
@@ -24,7 +24,7 @@ public:
     QmlSymbol *resolveType(QmlJS::AST::UiQualifiedId *name)
     { return resolveType(toString(name), _doc->fileName()); }
 
-    DuiDocument::Ptr document() const
+    QmlDocument::Ptr document() const
     { return _doc; }
 
     QList<QmlSymbol*> visibleSymbols(QmlJS::AST::Node *scope);
@@ -41,12 +41,12 @@ private:
 
 private:
     QStack<QmlJS::AST::Node *> _scopes;
-    DuiDocument::Ptr _doc;
+    QmlDocument::Ptr _doc;
     Snapshot _snapshot;
     QList<QmlSymbol*> _temporarySymbols;
 };
 
 } // namespace Internal
-} // namespace DuiEditor
+} // namespace QmlEditor
 
 #endif // QMLLOOKUPCONTEXT_H
diff --git a/src/plugins/duieditor/duimodelmanager.cpp b/src/plugins/qmleditor/qmlmodelmanager.cpp
similarity index 78%
rename from src/plugins/duieditor/duimodelmanager.cpp
rename to src/plugins/qmleditor/qmlmodelmanager.cpp
index 5645c8cc424e5fed5bccabf8285c3fe26fcde968..4a229e47441dec8660f87dc8d521c970b6214b89 100644
--- a/src/plugins/duieditor/duimodelmanager.cpp
+++ b/src/plugins/qmleditor/qmlmodelmanager.cpp
@@ -38,36 +38,36 @@
 
 #include <texteditor/itexteditor.h>
 
-#include "duieditorconstants.h"
-#include "duimodelmanager.h"
+#include "qmleditorconstants.h"
+#include "qmlmodelmanager.h"
 
-using namespace DuiEditor;
-using namespace DuiEditor::Internal;
+using namespace QmlEditor;
+using namespace QmlEditor::Internal;
 
-DuiModelManager::DuiModelManager(QObject *parent):
-        DuiModelManagerInterface(parent),
+QmlModelManager::QmlModelManager(QObject *parent):
+        QmlModelManagerInterface(parent),
         m_core(Core::ICore::instance())
 {
     m_synchronizer.setCancelOnWait(true);
 
-    qRegisterMetaType<DuiDocument::Ptr>("DuiDocument::Ptr");
+    qRegisterMetaType<QmlDocument::Ptr>("QmlDocument::Ptr");
 
-    connect(this, SIGNAL(documentUpdated(DuiDocument::Ptr)), this, SLOT(onDocumentUpdated(DuiDocument::Ptr)));
+    connect(this, SIGNAL(documentUpdated(QmlDocument::Ptr)), this, SLOT(onDocumentUpdated(QmlDocument::Ptr)));
 }
 
-Snapshot DuiModelManager::snapshot() const
+Snapshot QmlModelManager::snapshot() const
 {
     QMutexLocker locker(&m_mutex);
 
     return _snapshot;
 }
 
-void DuiModelManager::updateSourceFiles(const QStringList &files)
+void QmlModelManager::updateSourceFiles(const QStringList &files)
 {
     refreshSourceFiles(files);
 }
 
-QFuture<void> DuiModelManager::refreshSourceFiles(const QStringList &sourceFiles)
+QFuture<void> QmlModelManager::refreshSourceFiles(const QStringList &sourceFiles)
 {
     if (sourceFiles.isEmpty()) {
         return QFuture<void>();
@@ -75,7 +75,7 @@ QFuture<void> DuiModelManager::refreshSourceFiles(const QStringList &sourceFiles
 
     const QMap<QString, QString> workingCopy = buildWorkingCopyList();
 
-    QFuture<void> result = QtConcurrent::run(&DuiModelManager::parse,
+    QFuture<void> result = QtConcurrent::run(&QmlModelManager::parse,
                                               workingCopy, sourceFiles,
                                               this);
 
@@ -94,14 +94,14 @@ QFuture<void> DuiModelManager::refreshSourceFiles(const QStringList &sourceFiles
 
     if (sourceFiles.count() > 1) {
         m_core->progressManager()->addTask(result, tr("Indexing"),
-                        DuiEditor::Constants::TASK_INDEX,
+                        QmlEditor::Constants::TASK_INDEX,
                         Core::ProgressManager::CloseOnSuccess);
     }
 
     return result;
 }
 
-QMap<QString, QString> DuiModelManager::buildWorkingCopyList()
+QMap<QString, QString> QmlModelManager::buildWorkingCopyList()
 {
     QMap<QString, QString> workingCopy;
     Core::EditorManager *editorManager = m_core->editorManager();
@@ -117,20 +117,20 @@ QMap<QString, QString> DuiModelManager::buildWorkingCopyList()
     return workingCopy;
 }
 
-void DuiModelManager::emitDocumentUpdated(DuiDocument::Ptr doc)
+void QmlModelManager::emitDocumentUpdated(QmlDocument::Ptr doc)
 { emit documentUpdated(doc); }
 
-void DuiModelManager::onDocumentUpdated(DuiDocument::Ptr doc)
+void QmlModelManager::onDocumentUpdated(QmlDocument::Ptr doc)
 {
     QMutexLocker locker(&m_mutex);
 
     _snapshot.insert(doc);
 }
 
-void DuiModelManager::parse(QFutureInterface<void> &future,
+void QmlModelManager::parse(QFutureInterface<void> &future,
                             QMap<QString, QString> workingCopy,
                             QStringList files,
-                            DuiModelManager *modelManager)
+                            QmlModelManager *modelManager)
 {
     future.setProgressRange(0, files.size());
 
@@ -152,7 +152,7 @@ void DuiModelManager::parse(QFutureInterface<void> &future,
             }
         }
 
-        DuiDocument::Ptr doc = DuiDocument::create(fileName);
+        QmlDocument::Ptr doc = QmlDocument::create(fileName);
         doc->setSource(contents);
         doc->parse();
 
diff --git a/src/plugins/duieditor/duimodelmanager.h b/src/plugins/qmleditor/qmlmodelmanager.h
similarity index 81%
rename from src/plugins/duieditor/duimodelmanager.h
rename to src/plugins/qmleditor/qmlmodelmanager.h
index 436571c81e7e6277d8f784fb5b3d21fcb21336e3..4eb1f408b66e77a59b70964db39768f23847b264 100644
--- a/src/plugins/duieditor/duimodelmanager.h
+++ b/src/plugins/qmleditor/qmlmodelmanager.h
@@ -27,44 +27,44 @@
 **
 **************************************************************************/
 
-#ifndef DUIMODELMANAGER_H
-#define DUIMODELMANAGER_H
+#ifndef QMLMODELMANAGER_H
+#define QMLMODELMANAGER_H
 
 #include <QFuture>
 #include <QFutureSynchronizer>
 #include <QMutex>
 
-#include "duidocument.h"
-#include "duimodelmanagerinterface.h"
+#include "qmldocument.h"
+#include "qmlmodelmanagerinterface.h"
 
 namespace Core {
 class ICore;
 }
 
-namespace DuiEditor {
+namespace QmlEditor {
 namespace Internal {
 
-class DuiModelManager: public DuiModelManagerInterface
+class QmlModelManager: public QmlModelManagerInterface
 {
     Q_OBJECT
 
 public:
-    DuiModelManager(QObject *parent = 0);
+    QmlModelManager(QObject *parent = 0);
 
     virtual Snapshot snapshot() const;
     virtual void updateSourceFiles(const QStringList &files);
 
-    void emitDocumentUpdated(DuiDocument::Ptr doc);
+    void emitDocumentUpdated(QmlDocument::Ptr doc);
 
 Q_SIGNALS:
     void projectPathChanged(const QString &projectPath);
 
-    void documentUpdated(DuiDocument::Ptr doc);
+    void documentUpdated(QmlDocument::Ptr doc);
     void aboutToRemoveFiles(const QStringList &files);
 
 private Q_SLOTS:
     // this should be executed in the GUI thread.
-    void onDocumentUpdated(DuiDocument::Ptr doc);
+    void onDocumentUpdated(QmlDocument::Ptr doc);
 
 protected:
     QFuture<void> refreshSourceFiles(const QStringList &sourceFiles);
@@ -73,7 +73,7 @@ protected:
     static void parse(QFutureInterface<void> &future,
                       QMap<QString, QString> workingCopy,
                       QStringList files,
-                      DuiModelManager *modelManager);
+                      QmlModelManager *modelManager);
 
 private:
     mutable QMutex m_mutex;
@@ -84,6 +84,6 @@ private:
 };
 
 } // namespace Internal
-} // namespace DuiEditor
+} // namespace QmlEditor
 
-#endif // DUIMODELMANAGER_H
+#endif // QMLMODELMANAGER_H
diff --git a/src/plugins/duieditor/duimodelmanagerinterface.cpp b/src/plugins/qmleditor/qmlmodelmanagerinterface.cpp
similarity index 87%
rename from src/plugins/duieditor/duimodelmanagerinterface.cpp
rename to src/plugins/qmleditor/qmlmodelmanagerinterface.cpp
index 3143673761d6014d47fdd6c8a7988fd93886dab5..774c3ffb5db6f3c441c68219ecc0e7ac50d55c1c 100644
--- a/src/plugins/duieditor/duimodelmanagerinterface.cpp
+++ b/src/plugins/qmleditor/qmlmodelmanagerinterface.cpp
@@ -27,15 +27,15 @@
 **
 **************************************************************************/
 
-#include "duimodelmanagerinterface.h"
+#include "qmlmodelmanagerinterface.h"
 
-using namespace DuiEditor;
+using namespace QmlEditor;
 
-DuiModelManagerInterface::DuiModelManagerInterface(QObject *parent):
+QmlModelManagerInterface::QmlModelManagerInterface(QObject *parent):
     QObject(parent)
 {
 }
 
-DuiModelManagerInterface::~DuiModelManagerInterface()
+QmlModelManagerInterface::~QmlModelManagerInterface()
 {
 }
diff --git a/src/plugins/duieditor/duimodelmanagerinterface.h b/src/plugins/qmleditor/qmlmodelmanagerinterface.h
similarity index 81%
rename from src/plugins/duieditor/duimodelmanagerinterface.h
rename to src/plugins/qmleditor/qmlmodelmanagerinterface.h
index abbbf57ba9c43a0ce8437fa9d2cb1ab2d0bb400a..4adcf91bd0a459a4fc77287221a20c21021d8b8d 100644
--- a/src/plugins/duieditor/duimodelmanagerinterface.h
+++ b/src/plugins/qmleditor/qmlmodelmanagerinterface.h
@@ -27,25 +27,25 @@
 **
 **************************************************************************/
 
-#ifndef DUIMODELMANAGERINTERFACE_H
-#define DUIMODELMANAGERINTERFACE_H
+#ifndef QMLMODELMANAGERINTERFACE_H
+#define QMLMODELMANAGERINTERFACE_H
 
 #include <QObject>
 #include <QStringList>
 
-#include <duieditor/duieditor_global.h>
+#include <qmleditor/qmleditor_global.h>
 
-namespace DuiEditor {
+namespace QmlEditor {
 
 class Snapshot;
 
-class DUIEDITOR_EXPORT DuiModelManagerInterface: public QObject
+class QMLEDITOR_EXPORT QmlModelManagerInterface: public QObject
 {
     Q_OBJECT
 
 public:
-    DuiModelManagerInterface(QObject *parent = 0);
-    virtual ~DuiModelManagerInterface();
+    QmlModelManagerInterface(QObject *parent = 0);
+    virtual ~QmlModelManagerInterface();
 
     virtual Snapshot snapshot() const = 0;
     virtual void updateSourceFiles(const QStringList &files) = 0;
@@ -53,4 +53,4 @@ public:
 
 }
 
-#endif // DUIMODELMANAGERINTERFACE_H
+#endif // QMLMODELMANAGERINTERFACE_H
diff --git a/src/plugins/duieditor/qmlresolveexpression.cpp b/src/plugins/qmleditor/qmlresolveexpression.cpp
similarity index 98%
rename from src/plugins/duieditor/qmlresolveexpression.cpp
rename to src/plugins/qmleditor/qmlresolveexpression.cpp
index 02fc21daa7f4004d9f69dacf25e4789b32324795..89c7090a4d42e1d6e4c9dccb985321ed18a99b66 100644
--- a/src/plugins/duieditor/qmlresolveexpression.cpp
+++ b/src/plugins/qmleditor/qmlresolveexpression.cpp
@@ -2,8 +2,8 @@
 #include "qmljsengine_p.h"
 #include "qmlresolveexpression.h"
 
-using namespace DuiEditor;
-using namespace DuiEditor::Internal;
+using namespace QmlEditor;
+using namespace QmlEditor::Internal;
 using namespace QmlJS;
 using namespace QmlJS::AST;
 
diff --git a/src/plugins/duieditor/qmlresolveexpression.h b/src/plugins/qmleditor/qmlresolveexpression.h
similarity index 95%
rename from src/plugins/duieditor/qmlresolveexpression.h
rename to src/plugins/qmleditor/qmlresolveexpression.h
index 0a568aa0c753ad999bd45ab17db77e02ff76b39e..b756887f4a4e61c98235e3ddbf77d2a07132a786 100644
--- a/src/plugins/duieditor/qmlresolveexpression.h
+++ b/src/plugins/qmleditor/qmlresolveexpression.h
@@ -5,7 +5,7 @@
 #include "qmllookupcontext.h"
 #include "qmlsymbol.h"
 
-namespace DuiEditor {
+namespace QmlEditor {
 namespace Internal {
 
 class QmlResolveExpression: protected QmlJS::AST::Visitor
@@ -38,6 +38,6 @@ private:
 };
 
 } // namespace Internal
-} // namespace DuiEditor
+} // namespace QmlEditor
 
 #endif // QMLRESOLVEEXPRESSION_H
diff --git a/src/plugins/duieditor/qmlsymbol.cpp b/src/plugins/qmleditor/qmlsymbol.cpp
similarity index 98%
rename from src/plugins/duieditor/qmlsymbol.cpp
rename to src/plugins/qmleditor/qmlsymbol.cpp
index 196262ff2f58b04482bf4ec0f268d205035f8eb2..21271fb709997fd4687d19e5b63efd1c91f2c46c 100644
--- a/src/plugins/duieditor/qmlsymbol.cpp
+++ b/src/plugins/qmleditor/qmlsymbol.cpp
@@ -1,7 +1,7 @@
 #include "qmljsast_p.h"
 #include "qmlsymbol.h"
 
-using namespace DuiEditor;
+using namespace QmlEditor;
 using namespace QmlJS;
 using namespace QmlJS::AST;
 
diff --git a/src/plugins/duieditor/qmlsymbol.h b/src/plugins/qmleditor/qmlsymbol.h
similarity index 97%
rename from src/plugins/duieditor/qmlsymbol.h
rename to src/plugins/qmleditor/qmlsymbol.h
index 48509e6f6247e002090bb388911fa1107b0b2026..be827faea245b59ac57123ea547ffb1a15e3c583 100644
--- a/src/plugins/duieditor/qmlsymbol.h
+++ b/src/plugins/qmleditor/qmlsymbol.h
@@ -5,7 +5,7 @@
 
 #include "qmljsastfwd_p.h"
 
-namespace DuiEditor {
+namespace QmlEditor {
 
 class QmlSymbol
 {
@@ -87,6 +87,6 @@ private:
     QmlJS::AST::UiPublicMember *propertyNode() const;
 };
 
-} // namespace DuiEditor
+} // namespace QmlEditor
 
 #endif // QMLSYMBOL_H
diff --git a/src/plugins/duieditor/rewriter/rewriter.cpp b/src/plugins/qmleditor/rewriter/rewriter.cpp
similarity index 100%
rename from src/plugins/duieditor/rewriter/rewriter.cpp
rename to src/plugins/qmleditor/rewriter/rewriter.cpp
diff --git a/src/plugins/duieditor/rewriter/rewriter.pri b/src/plugins/qmleditor/rewriter/rewriter.pri
similarity index 100%
rename from src/plugins/duieditor/rewriter/rewriter.pri
rename to src/plugins/qmleditor/rewriter/rewriter.pri
diff --git a/src/plugins/duieditor/rewriter/rewriter_p.h b/src/plugins/qmleditor/rewriter/rewriter_p.h
similarity index 100%
rename from src/plugins/duieditor/rewriter/rewriter_p.h
rename to src/plugins/qmleditor/rewriter/rewriter_p.h
diff --git a/src/plugins/duieditor/rewriter/textwriter.cpp b/src/plugins/qmleditor/rewriter/textwriter.cpp
similarity index 100%
rename from src/plugins/duieditor/rewriter/textwriter.cpp
rename to src/plugins/qmleditor/rewriter/textwriter.cpp
diff --git a/src/plugins/duieditor/rewriter/textwriter_p.h b/src/plugins/qmleditor/rewriter/textwriter_p.h
similarity index 100%
rename from src/plugins/duieditor/rewriter/textwriter_p.h
rename to src/plugins/qmleditor/rewriter/textwriter_p.h
diff --git a/src/plugins/qmlprojectmanager/qmlproject.cpp b/src/plugins/qmlprojectmanager/qmlproject.cpp
index f65944933ee331a6b3b0044028fe6371ab4675fd..2e1133a16693a3b8e9979449535bf7fd6119a479 100644
--- a/src/plugins/qmlprojectmanager/qmlproject.cpp
+++ b/src/plugins/qmlprojectmanager/qmlproject.cpp
@@ -40,7 +40,7 @@
 #include <coreplugin/icore.h>
 #include <coreplugin/editormanager/editormanager.h>
 
-#include <duieditor/duimodelmanagerinterface.h>
+#include <qmleditor/qmlmodelmanagerinterface.h>
 
 #include <utils/synchronousprocess.h>
 #include <utils/pathchooser.h>
@@ -67,7 +67,7 @@ using namespace QmlProjectManager::Internal;
 QmlProject::QmlProject(Manager *manager, const QString &fileName)
     : m_manager(manager),
       m_fileName(fileName),
-      m_modelManager(ExtensionSystem::PluginManager::instance()->getObject<DuiEditor::DuiModelManagerInterface>())
+      m_modelManager(ExtensionSystem::PluginManager::instance()->getObject<QmlEditor::QmlModelManagerInterface>())
 {
     QFileInfo fileInfo(m_fileName);
     m_projectName = fileInfo.completeBaseName();
diff --git a/src/plugins/qmlprojectmanager/qmlproject.h b/src/plugins/qmlprojectmanager/qmlproject.h
index b53a3930d93ce8b2867db5b6f4dc62e8510d2299..08ac9aab71fabf78417b1a656400b751741051da 100644
--- a/src/plugins/qmlprojectmanager/qmlproject.h
+++ b/src/plugins/qmlprojectmanager/qmlproject.h
@@ -41,8 +41,8 @@
 
 #include <QtCore/QDir>
 
-namespace DuiEditor {
-class DuiModelManagerInterface;
+namespace QmlEditor {
+class QmlModelManagerInterface;
 }
 
 namespace QmlProjectManager {
@@ -108,7 +108,7 @@ private:
     QString m_filesFileName;
     QmlProjectFile *m_file;
     QString m_projectName;
-    DuiEditor::DuiModelManagerInterface *m_modelManager;
+    QmlEditor::QmlModelManagerInterface *m_modelManager;
 
     QStringList m_files;
 
diff --git a/src/plugins/qmlprojectmanager/qmlprojectmanager_dependencies.pri b/src/plugins/qmlprojectmanager/qmlprojectmanager_dependencies.pri
index 7fc59c9303166a2825a5cb6c6dc1c7ea9fa761c7..5a4e4cd588ffd1ad62696e16bf584b81833c9f80 100644
--- a/src/plugins/qmlprojectmanager/qmlprojectmanager_dependencies.pri
+++ b/src/plugins/qmlprojectmanager/qmlprojectmanager_dependencies.pri
@@ -1,3 +1,3 @@
 include(../../plugins/projectexplorer/projectexplorer.pri)
 include(../../plugins/texteditor/texteditor.pri)
-include(../../plugins/duieditor/duieditor.pri)
+include(../../plugins/qmleditor/qmleditor.pri)
diff --git a/src/plugins/duieditor/duicodecompletion.h b/src/plugins/qmleditor/qmlcodecompletion.h
similarity index 76%
rename from src/plugins/duieditor/duicodecompletion.h
rename to src/plugins/qmleditor/qmlcodecompletion.h
index dbd91b15cfb4b1aada308394dd317cd44a85e1c4..fd5e4b1ba62852f2a3194c69c97ac0ce6a5a541e 100644
--- a/src/plugins/duieditor/duicodecompletion.h
+++ b/src/plugins/qmleditor/qmlcodecompletion.h
@@ -1,5 +1,5 @@
-#ifndef DUICODECOMPLETION_H
-#define DUICODECOMPLETION_H
+#ifndef QMLCODECOMPLETION_H
+#define QMLCODECOMPLETION_H
 
 #include <texteditor/icompletioncollector.h>
 
@@ -7,16 +7,16 @@ namespace TextEditor {
 class ITextEditable;
 }
 
-namespace DuiEditor {
+namespace QmlEditor {
 namespace Internal {
 
-class DuiCodeCompletion: public TextEditor::ICompletionCollector
+class QmlCodeCompletion: public TextEditor::ICompletionCollector
 {
     Q_OBJECT
 
 public:
-    DuiCodeCompletion(QObject *parent = 0);
-    virtual ~DuiCodeCompletion();
+    QmlCodeCompletion(QObject *parent = 0);
+    virtual ~QmlCodeCompletion();
 
     Qt::CaseSensitivity caseSensitivity() const;
     void setCaseSensitivity(Qt::CaseSensitivity caseSensitivity);
@@ -38,6 +38,6 @@ private:
 
 
 } // end of namespace Internal
-} // end of namespace DuiEditor
+} // end of namespace QmlEditor
 
-#endif // DUICODECOMPLETION_H
+#endif // QMLCODECOMPLETION_H
diff --git a/src/plugins/duieditor/duidocument.h b/src/plugins/qmleditor/qmldocument.h
similarity index 75%
rename from src/plugins/duieditor/duidocument.h
rename to src/plugins/qmleditor/qmldocument.h
index 94fa1af681f168ae4503f766277088e68977495f..7639d1b25ac139ccada1a8b02b2f1f3413d6e780 100644
--- a/src/plugins/duieditor/duidocument.h
+++ b/src/plugins/qmleditor/qmldocument.h
@@ -26,8 +26,8 @@
 ** contact the sales department at http://qt.nokia.com/contact.
 **
 **************************************************************************/
-#ifndef DUIDOCUMENT_H
-#define DUIDOCUMENT_H
+#ifndef QMLDOCUMENT_H
+#define QMLDOCUMENT_H
 
 #include <QtCore/QList>
 #include <QtCore/QMap>
@@ -35,27 +35,27 @@
 #include <QtCore/QSharedPointer>
 #include <QtCore/QString>
 
-#include "duieditor_global.h"
+#include "qmleditor_global.h"
 #include "qmljsengine_p.h"
 #include "qmljsastfwd_p.h"
 #include "qmlsymbol.h"
 
-namespace DuiEditor {
+namespace QmlEditor {
 
-class DUIEDITOR_EXPORT DuiDocument
+class QMLEDITOR_EXPORT QmlDocument
 {
 public:
-    typedef QSharedPointer<DuiDocument> Ptr;
-    typedef QList<DuiDocument::Ptr> PtrList;
+    typedef QSharedPointer<QmlDocument> Ptr;
+    typedef QList<QmlDocument::Ptr> PtrList;
     typedef QMap<QString, QmlIdSymbol*> IdTable;
 
 protected:
-    DuiDocument(const QString &fileName);
+    QmlDocument(const QString &fileName);
 
 public:
-    ~DuiDocument();
+    ~QmlDocument();
 
-    static DuiDocument::Ptr create(const QString &fileName);
+    static QmlDocument::Ptr create(const QString &fileName);
 
     QmlJS::AST::UiProgram *program() const;
     QList<QmlJS::DiagnosticMessage> diagnosticMessages() const;
@@ -87,21 +87,21 @@ private:
     IdTable _ids;
 };
 
-class DUIEDITOR_EXPORT Snapshot: public QMap<QString, DuiDocument::Ptr>
+class QMLEDITOR_EXPORT Snapshot: public QMap<QString, QmlDocument::Ptr>
 {
 public:
     Snapshot();
     ~Snapshot();
 
-    void insert(const DuiDocument::Ptr &document);
+    void insert(const QmlDocument::Ptr &document);
 
-    DuiDocument::Ptr document(const QString &fileName) const
+    QmlDocument::Ptr document(const QString &fileName) const
     { return value(fileName); }
 
-    DuiDocument::PtrList importedDocuments(const DuiDocument::Ptr &doc, const QString &importPath) const;
-    QMap<QString, DuiDocument::Ptr> componentsDefinedByImportedDocuments(const DuiDocument::Ptr &doc, const QString &importPath) const;
+    QmlDocument::PtrList importedDocuments(const QmlDocument::Ptr &doc, const QString &importPath) const;
+    QMap<QString, QmlDocument::Ptr> componentsDefinedByImportedDocuments(const QmlDocument::Ptr &doc, const QString &importPath) const;
 };
 
-} // emd of namespace DuiEditor
+} // emd of namespace QmlEditor
 
-#endif // DUIDOCUMENT_H
+#endif // QMLDOCUMENT_H